<?php
	require_once('include/connection.php'); // mysql connection
	require_once('include/preload.php'); // texts and global settings

	require_once('include/tables.php'); // basic tables with data structure
	require_once('include/support.php'); // support functions
	require_once('include/format.php'); // formatting and displaying text and data
	require_once('include/taxonomy.php'); // operating with data and its structure
	require_once('include/values.php'); // getting values from tables
	require_once('include/ui.php'); // displaying values in profiles, comparison rankings
	require_once('include/dialogs.php'); // windows used for navigation and selection

	// if no object for comparison is selected, compare objects stored in basket (cookies)
	if (strlen($C_ENT) > 0 && !isset($_GET["objects"]))
		header('Location: /comparison/'.$C_ENT.'/'.$GS["newest_year"]);
		
	require_once('structure/header.php');
	
	if ($GS["caching_enabled"])
		require_once('structure/caching-header.php'); // all content generated after main menu can be cached and generated from cache

	$PAGE = "comparison";	// global variable used in functions for displaying values to determine how values should be displayed
?>

	<script type="text/javascript" src="/js/jquery-1.11.1.min.js"></script>
  <script type="text/javascript" src="/js/tipped.js"></script>

  <script type="text/javascript" 
  	src="https://www.google.com/jsapi?autoload=
    	{
        'modules':
        [{
          'name':'visualization',
          'version':'1',
          'packages':['corechart']
        }]
      }">
  </script>

	<script type="text/javascript">
		// initialize tooltips
    $(document).ready(function() {
      Tipped.create('.i-disclaimer', {fadeIn: 100, fadeOut: 100, behavior: 'hide'});
      Tipped.create('.legend', {fadeIn: 100, fadeOut: 100, behavior: 'hide'});
    });
  </script>
          
<?php
	// get objects and years to compare
	if (isset($_GET["objects"])) $object_string = $_GET["objects"]; else $object_string = NULL;
	if (!preg_match("/^[0-9a-zA-Z-,]+$/", $object_string)) $object_string = NULL;

	if (isset($_GET["years"])) $years = $_GET["years"]; else $years = NULL;
	if (!preg_match("/^[0-9]+$/", $years)) $years = NULL;

	if (!is_numeric($years)) $years = $GS["newest_year"];
	
	$years_a = parse_years($years);
	$raw_objects = parse_objects($object_string);
	
	$objects = array();
	foreach ($raw_objects as $raw_object)
		if (is_entity($raw_object) || is_aggregate($raw_object))
			$objects[] = $raw_object;
		
 	$objects = array_slice($objects, 0, $GS["comparison_object_limit"]);
	$obj_count = count($objects);
	
	// initialize variables
	$data = array();
	$indicators = array();
	$ratings = array();
	$disc_data = array();
	$disc_indicators = array();
	$disc_ratings = array();
	$names = array();
	$geo_a = array();
	$hie_a = array();
	
	// get values
	foreach ($objects as $obj_string)
	{
		$is_entity = is_entity($obj_string);
		$is_aggregate = is_aggregate($obj_string);
		$names[] = get_obj_name($obj_string);
		
		$geo = get_geo($obj_string);
		$geo_a[] = $geo;
		$hie = get_hie($obj_string);
		$hie_a[] = $hie;
		$geo_level = get_geo_level($obj_string);
		$hie_level = get_hie_level($obj_string);
		
		$numeric_data = get_data($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $years_a);
		$text_data = get_text_data($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $years_a);
		$data[] = $numeric_data[0] + $text_data[0]; // values itself
		$disc_data[] = $numeric_data[1] + $text_data[1]; // disclaimer IDs for some values (if needed)
		
		$I_array = get_indicators($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $GS["comparison_indicator_rating"], $years_a);	
		$indicators[] = $I_array[0]; // values itself
		$disc_indicators[] = $I_array[1]; // disclaimer IDs for some values (if needed)
		
		$R_array = get_ratings($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $years_a);
		$ratings[] = $R_array[0]; // values itself
		$disc_ratings[] = $R_array[1]; // disclaimer IDs for some values (if needed)
	}
	
	$names_string = implode(";", $names);	
	$objects_string = implode(",", $objects);
							
?>
			
<div class="years-wrapper">
  <div class="years-content-wrapper">
    <div class="years-content">
    
      <?php
        draw_years(); // draw panels with year selection
      ?>        
    
    </div>
  </div>
</div>
    
<div class="comparison-wrapper">

  <?php if ($obj_count > 0) { ?>
  
    <div class="compnav-wrapper">
      <div class="compnav-content-wrapper">
        <div id="compnav">
        
          <?php
            draw_comparison_navigation(); // draw panel with object names and buttons for their manipulation
          ?>
          
        </div>
      </div>
    </div>
    
  <?php
  }
  ?>
  
  <div class="comparison">
    <div id="comparison">
    
      <?php	
      
        if ($obj_count > 0)
        {
          $view = get_view($hie_a); // detect which data, indicators and ratings should be displayed for each object (entities with different hierarchy might have different types of data, indicators and ratings)
					
					// get specification for each type of data, indicator and rating
          if ($GS["max_data_level_allowed"] >= 0) $data_specs = get_specs("data", $view["data"][0]);
          if ($GS["max_indicator_level_allowed"] >= 0) $indicators_specs = get_specs("indicators", $view["indicators"][0]);
          if ($GS["max_rating_level_allowed"] >= 0) $ratings_specs = get_specs("ratings", $view["ratings"][0]);
          
					// detect which data, indicators and ratings do exist
          if ($GS["max_data_level_allowed"] >= 0) $data_existence = get_existence($view["data"]);
          if ($GS["max_indicator_level_allowed"] >= 0) $indicators_existence = get_existence($view["indicators"]);
          if ($GS["max_rating_level_allowed"] >= 0) $ratings_existence = get_existence($view["ratings"]);   
					
					// get disclaimers for current values
          if ($GS["max_data_level_allowed"] >= 0) $data_disclaimers = get_disclaimers("data", $disc_data);
          if ($GS["max_indicator_level_allowed"] >= 0) $indicator_disclaimers = get_disclaimers("indicators", $disc_indicators);
          if ($GS["max_rating_level_allowed"] >= 0) $rating_disclaimers = get_disclaimers("ratings", $disc_ratings);
                      
					// draw values (with their disclaimers, based on existence and specification)						
          if ($GS["max_rating_level_allowed"] >= 0) draw_ratings($ratings_specs, $ratings_existence, $ratings, $rating_disclaimers);
          if ($GS["max_indicator_level_allowed"] >= 0) draw_indicators($indicators_specs, $indicators_existence, $indicators, $indicator_disclaimers);	
          if ($GS["max_data_level_allowed"] >= 0) draw_data($data_specs, $data_existence, $data, $data_disclaimers);
        }
        else
        {
          echo '<div class="main-info">'.$T["i_add_first_object"].'</div>';
        }
      ?>
      
    </div>
  </div>  
</div>

<?php
	draw_cn_window();
?>
  
<?php
	require_once('structure/footer.php');

	if ($GS["caching_enabled"])
		require_once('structure/caching-footer.php');
?>