<?php

function get_mixed_color($first_value, $rating, $second_value, $first_colors, $second_colors)
{
	// get color of $rating based on $first value with its $first_colors and $second_value with its $second_colors using linear transformation
	// $first_colors, $second_colors - colors in HTML format
	
	$first_colors_a = hex2rgb($first_colors);
	$second_colors_a = hex2rgb($second_colors);	

	$r = $first_colors_a[0] + ($rating - $first_value)/($second_value - $first_value)*($second_colors_a[0] - $first_colors_a[0]);
	$g = $first_colors_a[1] + ($rating - $first_value)/($second_value - $first_value)*($second_colors_a[1] - $first_colors_a[1]);
	$b = $first_colors_a[2] + ($rating - $first_value)/($second_value - $first_value)*($second_colors_a[2] - $first_colors_a[2]);		
	
	return rgb2hex(array($r, $g, $b));
}

function get_rating_color($rating, $min_value, $max_value)
{
	// get color of $rating based on coloring specification in "rating_color_string" in "global_settings" table
	
	global $GS;
	
	if ($rating === NULL) return 'transparent';
	
	$rating = min(1, max(0, ($rating - $min_value) / ($max_value - $min_value))); // normalize rating to [0, 1];
	
	$color_string = $GS["rating_color_string"];
		
	if ($color_string == 'transparent') return 'transparent';
	
	// parsing $color_string
	// get first value and first color
	$defined_colors = explode(";", $color_string);
	$first = explode(":", $defined_colors[0]);
	$first_value = $first[0];
	$first_colors = $first[1];
	
	if ($rating < $first_value) return $first_colors;

	// iterating through all rating thresholds in $color_string
	for ($i = 0; $i < count($defined_colors) - 1; $i++)
	{
		$first = explode(":", $defined_colors[$i]);
		$second = explode(":", $defined_colors[$i+1]);
		$first_value = $first[0];
		$first_colors = $first[1];
		$second_value = $second[0];
		$second_colors = $second[1];
		
		// corresponding part of color string was found, calculate exact color based on colors of the nearest thresholds
		if ($rating >= $first_value && $rating < $second_value)
		{
			return get_mixed_color($first_value, $rating, $second_value, $first_colors, $second_colors);
		}
	}
	
	// no corresponding part of color string was found, meaning that rating is greater than color string allows
	if ($rating >= $second_value) return $second_colors;
}

function format($string, $datatype)
{
	// function for formatting value ($string) based on $datatype
	
	global $GS;
	
	// dealing with special cases
	if ($string == 'N/A') return $GS["missing_sign"];
	if ($string === NULL) return $GS["absence_sign"];
	
	if (substr($datatype, 0, 1) == 'n') // value is number
	{
		// define multiplier, decimal places, suffix; no prefix expected
		// "n(a, b, c)" means a - multiplier, b - decplaces, c - suffix; c must be enclosed in quotation marks
		// "n" := "n(1, 0, '')"
		// "n(a)" := "n(1, a, '')"
		// "n(a, b)" := "n(a, b, '')"
		
		$multiplier = 1;
		$decplaces = 0;
		$suffix = '';
		$datatype = str_replace("n", "", str_replace(")", "", str_replace("(", "", $datatype)));
		if ($datatype)
			$params = explode(",", $datatype);
		else
			$params = array();
		foreach ($params as &$param)
			$param = trim($param);
		if (count($params) == 1)
			$decplaces = $params[0];
		if (count($params) >= 2)
		{
			$multiplier = $params[0];
			$decplaces = $params[1];
		}
		if (count($params) == 3)
			$suffix = str_replace("'", "", str_replace('"', '', $params[2]));

		return number_format($multiplier * $string, $decplaces, $GS["decimal_separator"], $GS["thousand_separator"]) . $suffix;
	}
	
	if (substr($datatype, 0, 1) == 't') // value is text
	{
		// define max_length, cocatenating string
		// "t(a, b)" means a - maximum string length, b - cocatenating string when cocatenating multiple strings; b must be enclosed in quotation marks
		// "t" := "t(1048576, ', ')"
		// "t(a)" := "t(a, ', ')"
		
		$max_length = 1048576;
		$glue = ", ";
		$datatype = str_replace("t", "", str_replace(")", "", str_replace("(", "", $datatype)));
		if ($datatype) 
			$params = explode(",", $datatype);
		else
			$params = array();
		foreach ($params as &$param)
			$param = trim($param);
		if (count($params) >= 1)
			$max_length = intval($params[0]);
		if (count($params) == 2)
			$glue = str_replace("''", "", str_replace('""', '', $params[1]));
		$string = str_replace("#~", $glue, $string); // when concatenating multiple strings through mysql query, "#~" is used to concatenate
		$string = substr($string, 0, $max_length);
		return $string;
	}
	
	// datatype was not recognized
	return NULL;
}

function format_rating($string, $datatype, $min_rating, $max_rating)
{
	// function used for formating $rating based on $datatype and "rating_type" defined in "global_settings" table
	// rating_type:
	// 'default' - inherited from "datatype"
	// 'percentage' - formatted as percentage with given decimal precision
	// 'grades' - formatted as string (preferably one character) based on rating value
	
	global $GS;
	$ratingtype = $GS["rating_type"];
	
	if ($string === NULL) return '';
	
	// do not modify format of rating
	if ($ratingtype == 'default')
		return format($string, $datatype);

	// parse multiplier to display correct percentage
	$datatype = str_replace("n", "", str_replace(")", "", str_replace("(", "", $datatype)));		
	$params = explode(",", $datatype);
	$multiplier = 1;
	if (count($params) >= 2)
		$multiplier = $params[0];
	$string = $multiplier * $string;
	
	// "percentage:x" - x is number of decimal places
	if (substr($ratingtype, 0, 10) == 'percentage')
	{
		$decplaces = substr($ratingtype, 11);
		return number_format(min(100, max(0, 100*(($string - $min_rating)/($max_rating - $min_rating)))), $decplaces, $GS["decimal_separator"], "").' %';
	}
	
	// "grades:0.5#F;1#A" - if normalized rating is smaller than or equal to 0.5, return "F", else return "A"
	if (substr($ratingtype, 0, 6) == 'grades')
	{
		$string = floatval($string);
		$value = max(0, min(1, ($string - $min_rating)/($max_rating - $min_rating))); // normalize rating to [0, 1]
		$ratingtype = str_replace("grades:", "", $ratingtype);
		$thresholds = explode(";", $ratingtype);
		foreach ($thresholds as $threshold)
		{
			$elems = explode("#", $threshold);
			if ($value <= $elems[0]) // found corresponding threshold
				return $elems[1];
		}

		// no corresponding part of color grades string was found, meaning that rating is greater than grades string allows
		$elems = explode("#", $thresholds[count($thresholds)]);
		return $elems[1];
	}
}

function get_formatter_string($datatype)
{
	// function used for displaying google charts
	// output: [google locale]#[decimal places]#[suffix]
	global $GS;

	// only numbers can be formatted and displayed
	if (substr($datatype, 0, 1) != 'n') return NULL;

	$fs = $GS["google_locale"] . '#~';

	// default values for decimal places and suffix
	$decplaces = 0;
	$suffix = '';
	
	// parsing datatype - extracting decimal places and suffix
	$datatype = str_replace("n", "", str_replace(")", "", str_replace("(", "", $datatype)));
	$params = explode(",", $datatype);
	foreach ($params as &$param)
		$param = trim($param);
	if (count($params) == 1)
		$decplaces = $params[0];
	if (count($params) >= 2)
		$decplaces = $params[1];
	if (count($params) == 3)
		$suffix = str_replace("'", "", str_replace('"', '', $params[2]));

	// formatter string
	$fs .= $decplaces . '#~';	
	$fs .= $suffix;
	
	return $fs;
}

function format_legend($value, $legend_string)
{
	// function for parsing $legend_string based on $value
	// legend string example: "displaying {0||1# blue elements|2# green element| red elements} now" means:
	// - format $value to zero decimal places
	// - if value is smaller than 1, print "displaying 0 blue elements now"
	// - else, if value is smaller than 2, print "displaying 1 green element now"
	// else (if value is greater than or equal to 2), print "displaying [n] red elements" where n is $value
	
	global $GS;
	
	$remaining_string = $legend_string;
	$final_string = '';
	
	while (strpos($remaining_string, "{") !== FALSE)
	{
		// extract string between braces
		$left_bracket_position = strpos($remaining_string, "{");
		$right_bracket_position = strpos($remaining_string, "}");
		$final_string .= substr($remaining_string, 0, $left_bracket_position);
		$between_string = substr($remaining_string, $left_bracket_position + 1, $right_bracket_position -  $left_bracket_position - 1);
		$remaining_string = substr($remaining_string, $right_bracket_position + 1);
		
		// parse string between braces
		$elements = explode("||", $between_string);
		$decplaces = $elements[0];
		
		// print formatted $value
		$final_string .= number_format($value, $decplaces, $GS["decimal_separator"], $GS["thousand_separator"]);
		if (count($elements) > 1)
		{
			
			// find appropriate declension based on $value
			$declension = $elements[1];
			$variants = explode("|", $declension);
			foreach ($variants as $variant)
			{
				$parts = explode("#", $variant);
				if (is_numeric($parts[0]))
				{
					if ($value < $parts[0])
					{
						$final_string .= $parts[1];
						break;
					}
				}
				else 
				{
					$final_string .= $parts[0];
					break;
				}
			}
		}
	}
	
	$final_string .= $remaining_string;
	
	return $final_string;
}

function anchorize($html_text)
{
	// function for anchoring headers in pages containing only text from database
	// <h1> and <h2> present in $html_text will be anchored
	// <h1> - chapters
	// <h2> - subchapters
	
	$h1_count = 0;
	$h1_substring = $html_text;
	$final_string = '';
	$names_h1 = array(); // structure of chapters
	$names_h2 = array(); // structure of subchapters (multidim. array)
	
	while (strpos($h1_substring, "<h1>") !== FALSE) // iterating until last chapter is found
	{
		$h1_count++;
		$names_h2[$h1_count] = array(); // current chapter might have subchapters
		$h2_count = 0;
		$h1_start = strpos($h1_substring, "<h1>");
		$h1_end = strpos($h1_substring, "</h1>");
		
		$h2_substring = substr($h1_substring, 0, $h1_start);
		
		while (strpos($h2_substring, "<h2>") !== FALSE) // find and parse all subchapters of current chapter
		{
			$h2_count++;
			// extract subchapter name
			$h2_start = strpos($h2_substring, "<h2>");
			$h2_end = strpos($h2_substring, "</h2>");			
			$h2_between_string = substr($h2_substring, $h2_start + 4, $h2_end - $h2_start - 4);			
			
			// anchorize subchapter name
			$final_string .= substr($h2_substring, 0, $h2_start) . '<h2><a name="section-'.($h1_count-1).'-'.$h2_count.'">' . $h2_between_string . '</a></h1>';
			// add subchapter name to subchapters structure
			$names_h2[($h1_count-1)][$h2_count] = $h2_between_string;			
			// still, some text after last subchapter is remaining
			$h2_substring = substr($h2_substring, $h2_end + 5);
		}
		
		// add remaining text after last subchapter
		$final_string .= $h2_substring;

		// extract chapter name
		$h1_between_string = substr($h1_substring, $h1_start + 4, $h1_end - $h1_start - 4);
		// anchorize chapter name
		$final_string .= '<h1><a name="section-'.$h1_count.'-0">' . $h1_between_string . '</a></h1>';
		// add chapter name to chapters structure
		$names_h1[$h1_count] = $h1_between_string;
		// still, some text after last chapter is remaining
		$h1_substring = substr($h1_substring, $h1_end + 5);
	}
	
	$h1_count++;
	$h2_count = 0;
	
	// still, after last chapter, some subchapters may be present
	// find all subchapters after last chapter
	
	while (strpos($h1_substring, "<h2>") !== FALSE)
	{
		$h2_count++;
		// extract subchapter name
		$h2_start = strpos($h1_substring, "<h2>");
		$h2_end = strpos($h1_substring, "</h2>");
		$h2_between_string = substr($h1_substring, $h2_start + 4, $h2_end - $h2_start - 4);			
		
		// anchorize subchapter name
		$final_string .= substr($h1_substring, 0, $h2_start) . '<h2><a name="section-'.($h1_count-1).'-'.$h2_count.'">' . $h2_between_string . '</a></h1>';
		// add subchapter name to subchapters structure
		$names_h2[($h1_count-1)][$h2_count] = $h2_between_string;			
		// still, some text after last subchapter is remaining
		$h1_substring = substr($h1_substring, $h2_end + 5);
	}
	
	// add remaining text
	$final_string .= $h1_substring;
	
	return array($final_string, $names_h1, $names_h2);
}

?>