<?php

// functions for parsing and displaying special pages containing only text (no data or entities)

function display_text_page($html_text)
{
	global $T;
	
	$countH = substr_count($html_text, '<h1>') + substr_count($html_text, '<h2>');
	$anchored = anchorize($html_text);
	$text = $anchored[0];
	$names_h1 = $anchored[1];
	$names_h2 = $anchored[2];
	
	// when scrolling, stick table of contents to top or bottom of page to make it permanentny accessible
	echo '
	<script type="text/javascript">
		document.getElementById("body").onscroll = get_toc_class;
	</script>';
	
	echo '
	<div class="body-content-wrapper">
		<div class="body-content">
			<div class="text">
				<div id="toc" class="toc"><div>'; // displaying table of contents generated through anchorize(...)
				if ($countH > 0) // at least one chapter or subchapter
				{
					echo '<ul>';
					$h1_c = 0;
					foreach ($names_h1 as $name_h1) // iterate through chapters
					{
						$h1_c++;
						$h2_c = 0;
						echo '<li><a href="#section-'.$h1_c.'-'.$h2_c.'">'.$name_h1.'</a></li>'; // display chapter name
						if (count($names_h2[$h1_c]) > 0) // at least one subchapter
						{
							echo '<ul>';
							foreach ($names_h2[$h1_c] as $name_h2) // iterate through subchapters
							{
								$h2_c++;
								echo '<li><a href="#section-'.$h1_c.'-'.$h2_c.'">'.$name_h2.'</a></li>'; // display subchapter name
							}
							echo '</ul>';
						}
					}
					echo '</ul>';
				}
				echo '<span>&uarr;</span><a href="javascript:void(0)" onclick="window.scrollTo(0,0)">'.$T["back_to_top"].'</a>'; // display 'back to top' anchor
				echo '</div></div>';
				echo '<div class="content">';
				echo $text; // content of page
				echo '
				</div>
				<div class="clear"></div>
			</div>
		</div>
	</div>';
}

// error 404 or other errors (no search results found, no profile found, ...)
function display_error_page($text)
{
	echo '
	<div class="body-content-wrapper">
		<div class="body-content">			
			<div class="main-error">'.$text.'</div>		
		</div>
	</div>';
}

// explanation of $string structure is in explanation of "landing_layout" in "global settings"
// $string defines layout of particular page - landing page (index.php) or profiles page (profile.php)
function parse_display_string($string)
{
	global $GS, $T, $colcount;
	
	$elements = explode("##", $string);
	foreach ($elements as $element)
	{
		// get all elements
		$parts = explode("||", $element);
		$background = $parts[0];
		$content = $parts[1];
		$parts = explode(":", $content);
		$type = $parts[0];
		$display = $parts[1];
		
		// required for different classes than in other elements
		if ($type == 'navigation') 
			$special_class = " landing-nav"; 
		elseif ($type == 'tree')
			$special_class = " landing-tree";
		else
		 $special_class = "";
		
		echo '<div class="'.$background.'">';
			echo '<div class="body-content-wrapper">';
				echo '<div class="body-content">';
					echo '<div class="element-wrapper'.$special_class.'">';
					
						if ($type == 'disclaimer') // just echo content of disclaimer
						{
							echo '<div class="center">';
								echo $T["l_disclaimer"];
							echo '</div>';
						}
						// display one to four blocks - each block explains its part
						// each block contains heading - 'about', 'authors', 'web' or 'data' and its explanation
						if ($type == 'about') 
						{
							$about_elems = explode(",", $display);
							$class = "element-".(count($about_elems))." center";
							if (in_array("project", $about_elems))
							{
								echo '<div class="'.$class.'">';
									echo '<img class="icon" src="icons/project.png" width="52" height="51" />';
									echo '<h3>'.$T["l_project"].'</h3>';
									echo '<p>'.$T["l_project_text"].'</p>';
								echo '</div>';
							}
							if (in_array("authors", $about_elems))
							{
								echo '<div class="'.$class.'">';
									echo '<img class="icon" src="icons/authors.png" width="52" height="51" />';
									echo '<h3>'.$T["l_authors"].'</h3>';
									echo '<p>'.$T["l_authors_text"].'</p>';
								echo '</div>';
							}
							if (in_array("web", $about_elems))
							{
								echo '<div class="'.$class.'">';
									echo '<img class="icon" src="icons/web.png" width="51" height="49" />';
									echo '<h3>'.$T["l_web"].'</h3>';
									echo '<p>'.$T["l_web_text"].'</p>';
								echo '</div>';
							}
							if (in_array("data", $about_elems))
							{
								echo '<div class="'.$class.'">';
									echo '<img class="icon" src="icons/data.png" width="51" height="51" />';
									echo '<h3>'.$T["l_data"].'</h3>';
									echo '<p>'.$T["l_data_text"].'</p>';
								echo '</div>';
							}
							echo '<div class="clear"></div>';
						}
					
					 	// display one to four blocks that show main functions of web - ranking, profile, comparison and map
						// each block contains heading - 'rankings', 'profiles', 'comparison' or 'map', its thumbail, explanation and button navigating to particular page
						if ($type == 'navigation')
						{
							$nav_elems = explode(",", $display);
							$class = "element-".count($nav_elems)." center";
							if (in_array("rankings", $nav_elems))
							{
                echo '<div class="'.$class.'">';
                  echo '<a href="/rankings">';
                  echo '<img src="images/'.$GS["sample_ranking_image"].'"/>';
                  echo '</a>';
                  echo '<h3><a href="/rankings">'.$T["rankings"].'</a></h3>';
                  echo '<p>'.$T["l_rankings_text"].'</p>';
                  echo '<a class="button b-large b-yellow" href="/rankings">'.$T["l_create_own_ranking"].'</a>';
                echo '</div>';
							}
							if (in_array("profiles", $nav_elems))
							{
                echo '<div class="'.$class.'">';
                  echo '<a href="/profile">';
                  echo '<img src="images/'.$GS["sample_profile_image"].'"/>';
                  echo '</a>';
                  echo '<h3><a href="/profile">'.$T["profiles"].'</a></h3>';
                  echo '<p>'.$T["l_profiles_text"].'</p>';
                  echo '<a class="button b-large b-yellow" href="/profile">'.$T["l_select_profile"].'</a>';
                echo '</div>';
							}
							if (in_array("comparison", $nav_elems))
							{
                echo '<div class="'.$class.'">';
                  echo '<a href="/comparison">';
                  echo '<img src="images/'.$GS["sample_comparison_image"].'"/>';
                  echo '</a>';
                  echo '<h3><a href="/comparison">'.$T["comparison"].'</a></h3>';
                  echo '<p>'.$T["l_comparison_text"].'</p>';
                  echo '<a class="button b-large b-yellow" href="/comparison">'.$T["l_compare_entities"].'</a>';
                echo '</div>';
							}
							if (in_array("map", $nav_elems))
							{
                echo '<div class="'.$class.'">';
                  echo '<a href="/map">';
                  echo '<img src="images/'.$GS["sample_map_image"].'"/>';
                  echo '</a>';
                  echo '<h3><a href="/map">'.$T["map"].'</a></h3>';
                  echo '<p>'.$T["l_map_text"].'</p>';
                  echo '<a class="button b-large b-yellow" href="/map">'.$T["l_show_map"].'</a>';
                echo '</div>';
							}
			        echo '<div class="clear"></div>';
						}
					
						// display ranking based on given conditions - columns ($types), geography and hierarchy ($geo_hie), pagination including sort column and order ($pagination)
						if ($type == 'rankings')
						{
							$rankings = explode("#", $display);
							$class = "element-".count($rankings)." center";
							foreach ($rankings as $ranking)
							{
								$parts = explode("|", $ranking);
								$text = $parts[0];
								$criteria = explode(";", $parts[1]);
								$types = $criteria[0];
								$geo_hie = $criteria[1];
								$pagination = $criteria[2];
								$page_elems = explode(",", $pagination);

								echo '<div class="'.$class.'">';
									echo '<h3>'.$text.'</h3>';
									$data = get_ranking_values($types, $geo_hie, $GS["newest_year"], $pagination);
									// display ranking with very limited functions - without disclaimers, tooltips, header, sortability, higlighting sort column and pagination, only with first column
									draw_rankings($data, $types, $geo_hie, $GS["newest_year"], $pagination, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE);
									echo '<a class="button b-large b-gray" href="/rankings/'.$types.'/'.$geo_hie.'/'.$GS["newest_year"].'/'.$page_elems[0].','.$page_elems[1].',1-'.$GS["default_ranking_rows"].'">'.$T["l_show_full_ranking"].'</a>';
								echo '</div>';								
							}
							echo '<div class="clear"></div>';
						}
					
						// display list of selected entities including image thumbnails
						// image thumbnail must be located in "/images/" as "e-[ID].jpg", where ID is ID of entity
						if ($type == 'profiles')
						{
							echo '<div class="center">';
								echo '<h3>'.$T["l_selected_profiles"].'</h3>';
									echo '<div class="element-entities">';

										$list = preg_replace('/\s+/', '', $display);
										$list = explode(",", $list);
										$entities_data = get_entities_specs($list);
										foreach ($entities_data as $ID => $data)
										{
											echo '<div class="element-entity-wrapper">';
											echo '<div class="ee-photo"><img src="/images/e-'.$ID.'.jpg" /></div>';
											echo '<div class="ee-name"><a href="/profile/'.$data["ID"].'/'.$GS["newest_year"].'">'.$data["name"].'</a></div>';
											echo '</div>';
										}

									echo '<div class="clear"></div>';
									echo '</div>';
								echo '<a class="button b-large b-gray" href="/profile">'.$T["l_show_all_profiles"].'</a>';
							echo '</div>';
						}
						
						// display search element
						// may contain sarch box, alphabet - where each character represents first character of entity name and button for showing all entities
						if ($type == 'search')
						{
							$parts = explode("|", $display);
							$text = $parts[0];
							$elements = explode(",", $parts[1]);
          		echo '<div class="element-1 center">';
            	echo '<h3>'.$text.'</h3>';
							if (in_array("searchbox", $elements))
							{
								echo '<div id="search">';
                	echo '<input name="main-search" type="text" id="main-search" onkeypress="if (event.keyCode == 13) doSearch(\'main-search\');" placeholder="'.$T['search_placeholder_text'].'"/><a name="main-submit" id="main-submit" type="submit" onclick="doSearch(\'main-search\')"><img src="/icons/loupe-white.png" width="19" height="19" /></a>';
              	echo '</div>';
							}
							if (in_array("letters", $elements))
							{
              	echo '<div id="sbfl">';
								for ($i = 65; $i <= 90; $i++)
									echo '<a href="/search/name/'.strtolower(chr($i)).'">'.chr($i).'</a>';
	              echo '</div>';
              }
							if (in_array("button", $elements))
								echo '<a class="button b-large b-gray" href="/profile/all">'.$T["l_show_all_profiles"].'</a>';
	            echo '</div>';
						}
						
						// display geographical or hierarchical structure tree - making understating hierarchical and geographical structure easier
						if ($type == 'tree')
						{
							$parts = explode("|", $display);
							$text = $parts[0];
							$elements = explode(",", $parts[1]);
							echo '<div class="element-1 center">';
								echo '<h3>'.$text.'</h3>';
								$colcount = 0;
								$all_geos = reset(get_geos('0'));
								$all_hies = reset(get_hies('0'));
								echo '<div>';								
								if ($elements[0] == 'geography') draw_tree('geography', $all_geos, $all_hies, $elements[1]); 
								if ($elements[0] == 'hierarchy') draw_tree('hierarchy', $all_hies, $all_geos, $elements[1]); 
								echo '</div><div class="clear"></div>';
							echo '</div>';
						}
					
					echo '</div>';
				echo '</div>';
			echo '</div>';
		echo '</div>';
		
	}
}
		
?>