<?php

function in_list($list, $element)
{
	// check if $element is in $list
	// $list - string with elements separated by comma
	// $element - possibly one of elements in list
	
	$list_elements = explode(",", $list);
	if (is_array($list_elements))
		return in_array($element, $list_elements, TRUE);
	else
		return FALSE;
}

function add_to_list($list, $element)
{
	// add $element to $list
	// $list - string with elements separated by comma
	
	$list_elements = explode(",", $list);
	
	if (!in_list($list, $element))
		$list_elements[] = $element;
		
	return implode(",", $list_elements);
}

function remove_from_list($list, $element)
{
	// remove element from $list
	// $list - string with elements separated by comma
	
	$list_elements = explode(",", $list);
	
	if (in_list($list, $element))
	{
		$position = array_search($element, $list_elements);
		unset($list_elements[$position]);
	}
		
	return implode(",", $list_elements);	
}

function list_count($list)
{
	// count number of elements in $list
	
	if (strlen($list) == 0) 
		return 0;
	else
		return count(explode(",", $list));
}

function round_down($number, $to_digits)
{
	// "round" $number to $to_digits valid digits
	// round_down(1234567, 2) = 1200000
	
	$digits = floor(log10($number));
	$mult = pow(10, -($digits+1-$to_digits));
	return floor($number * $mult) / $mult;
}
	
function hex2rgb($hex)
{
	// converts color in HTML format to rgb
	// result: array(r, g, b)
	
  $hex = str_replace("#", "", $hex);

  if(strlen($hex) == 3) 
	{
    $r = hexdec(substr($hex,0,1).substr($hex,0,1));
    $g = hexdec(substr($hex,1,1).substr($hex,1,1));
    $b = hexdec(substr($hex,2,1).substr($hex,2,1));
  } else 
	{
    $r = hexdec(substr($hex,0,2));
    $g = hexdec(substr($hex,2,2));
    $b = hexdec(substr($hex,4,2));
  }
	
  $rgb = array($r, $g, $b);
  return $rgb;
}

function rgb2hex($rgb)
{
	// converts color in rgb format to HTML format
	// rgb format:  array(r, g, b)
	
  $hex = '';
	foreach ($rgb as &$color)
		$color = round($color);
		
  $hex .= str_pad(dechex($rgb[0]), 2, "0", STR_PAD_LEFT);
  $hex .= str_pad(dechex($rgb[1]), 2, "0", STR_PAD_LEFT);
  $hex .= str_pad(dechex($rgb[2]), 2, "0", STR_PAD_LEFT);

	$hex = '#' . $hex;
  return $hex;
}

function bind_array($stmt, &$row) 
{
	$md = $stmt->result_metadata();
	$params = array();
	
	while($field = $md->fetch_field()) 
		$params[] = &$row[$field->name];

	call_user_func_array(array($stmt, 'bind_result'), $params);
}

?>