<?php

// divide $year_string to first and last years
// $year_string is range of years separated by dash or just one year
function parse_years($year_string)
{
	$years = explode("-", $year_string);
	if (count($years) == 1) $years[1] = $years[0];
	return $years;
}

// split $obj_string into array of objects
function parse_objects($obj_string, $divider = ",")
{
	return explode($divider, $obj_string);
}

// detect if $obj_string is entity or not - if not, it may be aggregate or meaningless string
function is_entity($obj_string)
{
	global $con;
 
	$obj_query = mysqli_query($con, "SELECT * FROM `entities` WHERE `ID` = '".$obj_string."' AND `visibility` = 1");
	
	return (mysqli_num_rows($obj_query) > 0 ? 1 : 0);
}

// detect if $obj_string is aggregate or not - if not, it may be entity or meaningless string
// aggregate meeans that $obj_string is in form [geographical_structure ID]-[hierarchical_structure ID] aggregating all elements with specified geography and hierarchy
function is_aggregate($obj_string)
{
	global $con;
 
	$is_aggregate = 1;
	$IDs = explode("-", $obj_string);
	
	if (count($IDs == 2))
	{
		$geo_ID = $IDs[0];
		$hie_ID = $IDs[1];
		$geo_query = mysqli_query($con, "SELECT * FROM `geographical_structure` WHERE `ID` = '".$geo_ID."'");
		$hie_query = mysqli_query($con, "SELECT * FROM `hierarchical_structure` WHERE `ID` = '".$hie_ID."'");
		if (mysqli_num_rows($geo_query) == 0 || mysqli_num_rows($hie_query) == 0) // no entity with specified geography or hierarchy was found
			$is_aggregate = 0;
	}
	else
		$is_aggregate = 0;
		
	return $is_aggregate;
}

// retrieve specification of entity with $entity_ID
function get_entity_specs($entity_ID)
{
	global $con;
	
	$entity_query = mysqli_query($con, "SELECT * FROM `entities` WHERE `ID` = '".$entity_ID."'");
	
	return mysqli_fetch_array($entity_query);
}

// retrieve specification of entities in $entities_array
function get_entities_specs($entities_array, $order_by_name = FALSE)
{
	global $con;
	$output = array();

	// enclose each entity in quotation marks for query purposes
	foreach ($entities_array as &$entity)
		$entity = "'".$entity."'";
	$entities_string = implode(",", $entities_array);
	if (count($entities_array) == 0)
		$entities_string = "''";
	
	// how to order result	
	if ($order_by_name) 
		$order_string = "`entities`.`name` ASC, `entities`.`sub_name` ASC";
	else
		$order_string = "FIELD(`ID`, ".$entities_string.")";
	
	// query	
	$query_string = "SELECT * FROM `entities` WHERE `ID` IN (".$entities_string.") AND `visibility` = 1 ORDER BY ".$order_string;
	$query = mysqli_query($con, $query_string);
	while ($row = mysqli_fetch_array($query))
		$output[$row["ID"]] = $row;
	
	return $output;
}

// get geography of $obj_string
// if $obj_string is aggregate, simply take geography part
// if $obj_string is entity, get its geography from entity specs
function get_geo($obj_string)
{
	if (is_aggregate($obj_string))
	{
		$IDs = explode("-", $obj_string);
		return $IDs[0];
	}
	else
	{
		if (is_entity($obj_string))
		{
			$entity_specs = get_entity_specs($obj_string);
			return $entity_specs["geography"];
		}
		else return NULL;
	}
}

// get hierarchy of $obj_string
// if $obj_string is aggregate, simply take hierarchy part
// if $obj_string is entity, get its hierarchy from entity specs
function get_hie($obj_string)
{
	if (is_aggregate($obj_string))
	{
		$IDs = explode("-", $obj_string);
		return $IDs[1];
	}
	else
	{
		if (is_entity($obj_string))
		{
			$entity_specs = get_entity_specs($obj_string);
			return $entity_specs["hierarchy"];
		}
		else return NULL;
	}
}

// get geographical path of $obj_string (called breadcrumb) from bottom geography level to top (with level = 0)
function get_geo_bread($obj_string)
{
	global $geo_tree, $GS;	 
	
	$geo_bread = array();
	$current_geo = get_geo($obj_string); // bottom geography level
	
	while ($current_geo !== NULL) // climb through all geography levels until top level is found
	{
		$geo_bread[] = $current_geo; // write current geo
		$current_geo = $geo_tree[$current_geo]; // go up one level
	}
		
	$geo_bread = array_reverse($geo_bread); // reverse array, so elements will will be stored from top level to bottom
	return array_slice($geo_bread, 0, $GS["max_geography_level_allowed"] + 1);
}

// get hierarchical path of $obj_string (called breadcrumb) from bottom hierarchy level to top (with level = 0)
function get_hie_bread($obj_string)
{
	global $hie_tree, $GS;	 
	
	$hie_bread = array();
	$current_hie = get_hie($obj_string); // bottom hierarchy level
	
	while ($current_hie !== NULL) // climb through all hierarchy levels until top level is found
	{
		$hie_bread[] = $current_hie; // write current hie
		$current_hie = $hie_tree[$current_hie]; // go up one level
	}
	
	$hie_bread = array_reverse($hie_bread); // reverse array, so elements will will be stored from top level to bottom
	return array_slice($hie_bread, 0, $GS["max_hierarchy_level_allowed"] + 1);
}

// get geographical level of $obj_string
function get_geo_level($obj_string)
{
	global $geo_table;
	
	return $geo_table[get_geo($obj_string)]["level"];
}

// get hierarchical level of $obj_string
function get_hie_level($obj_string)
{
	global $hie_table;
	
	return $hie_table[get_hie($obj_string)]["level"];
}

// get names of individual elements of breadcrumb array fro $obj_string
function get_geo_bread_names($obj_string)
{
	global $geo_table;
	
	$geo_bread_names = array();
	$geo_bread = get_geo_bread($obj_string); // get breadcrumb IDs
	
	foreach ($geo_bread as $step)
		$geo_bread_names[] = $geo_table[$step]["text_multi"]; // get name for each ID
		
	return $geo_bread_names;
}

// get names of individual elements of breadcrumb array fro $obj_string
function get_hie_bread_names($obj_string)
{
	global $hie_table;
	
	$hie_bread_names = array();
	$hie_bread = get_hie_bread($obj_string); // get breadcrumb IDs
	
	foreach ($hie_bread as $step)
		$hie_bread_names[] = $hie_table[$step]["text_multi"]; // get name for each ID
		
	return $hie_bread_names;
}

// get all geography structure elements with specified level
function get_geos($level)
{
	global $geo_table;
	$geos = array();
	
	foreach ($geo_table as $geo_row)
		if ($geo_row["level"] === $level)
			$geos[$geo_row["ID"]] = $geo_row;
			
	return $geos;
}

// get all hierarchy structure elements with specified level
function get_hies($level)
{
	global $hie_table;
	$hies = array();
	
	foreach ($hie_table as $hie_row)
		if ($hie_row["level"] === $level)
			$hies[$hie_row["ID"]] = $hie_row;

	return $hies;
}

// get all children of geography structure element ($geo_parent)
function get_geo_children($geo_parent)
{
	global $geo_table;
	$children = array();
	
	foreach ($geo_table as $geo_row)
		if ($geo_row["parent_ID"] === $geo_parent)
			$children[] = $geo_row;
			
	return $children;
}

// get all children of hierarchy structure element ($hie_parent)
function get_hie_children($hie_parent)
{
	global $hie_table;
	$children = array();
	
	foreach ($hie_table as $hie_row)
		if ($hie_row["parent_ID"] === $hie_parent)
			$children[] = $hie_row;

	return $children;
}

// get name of object (entity or aggregate)
// if $average_text is TRUE and $object is aggregate, add text "average for" at the beginning of name
// if $br is true, $object is entity and has subname, display subname in new line
function get_obj_name($object, $average_text = TRUE, $br = FALSE)
{
	global $GS, $T;
	$is_entity = is_entity($object);
	$is_aggregate = is_aggregate($object);
	$geo_level = get_geo_level($object);
	$hie_level = get_hie_level($object);
	if ($is_entity)
		$entity_specification = get_entity_specs($object);
	$geo_bread_names = get_geo_bread_names($object); // names of geographical breadcrumb
	$hie_bread_names = get_hie_bread_names($object); // names of hierarchical breadcrumb

	$name = '';

	if ($is_aggregate && $geo_level < $GS["max_geography_level_allowed"] && $hie_level < $GS["max_hierarchy_level_allowed"] && $average_text) // is proper aggregate and text "average for" should be displayed
		$name .= $T["average_for"].' ';
		
	if ($is_entity)
	{
		// display name with its subname
		$name .= $entity_specification["name"];
		if ($entity_specification["sub_name"])
		{
			if ($br)
				$name .= '<br />';
			$name .= '<span>'.$entity_specification["sub_name"].'</span>';
		}
	}
	else
	{
		// is aggregate; if level of one dimension is equal to 0, do not mention this dimension in the name;
		if ($geo_level > 0 && $hie_level > 0)
			$name .= end($hie_bread_names).', '.end($geo_bread_names);
		if ($geo_level == 0 && $hie_level > 0)
			$name .= end($hie_bread_names);
		if ($geo_level > 0 && $hie_level == 0)
			$name .= end($geo_bread_names);
		if ($geo_level == 0 && $hie_level == 0)
			$name .= $T["all_geo_hie"];
	}
	
	return $name;
}

// get entities with geography equal to geo or any of its children and hierarchy equal to $hie or any of its children
function get_entities($geo, $hie)
{
	global $con, $geo_table, $hie_table, $max_geo_level, $max_hie_level;
	
	if ($geo !== FALSE)
	{
		$geo_level = $geo_table[$geo]["level"];
		$geo_from_bottom = $max_geo_level - $geo_level; // find how many levels is $geo from the bottom level of geographical structure
	}
	if ($hie !== FALSE)
	{
		$hie_level = $hie_table[$hie]["level"];
		$hie_from_bottom = $max_hie_level - $hie_level; // find how many levels is $hie from the bottom level of hierarchical structure
	}
	
	$query_string = 
	"SELECT 
	`entities`.*
	FROM `entities`";
	if ($geo !== FALSE)
	{
		$query_string .= " LEFT JOIN `geographical_structure` AS `g0` ON `entities`.`geography` = `g0`.`ID`";

		// $geo might be on any level - to iterate thgough all necessary levels (because table 'entities' stores only information about the lowest level, not about the whole path), table must be joined with itself, maybe even multiple times (based on number of levels)		
		for ($i = 1; $i <= $geo_from_bottom; $i++)
			$query_string .= " LEFT JOIN `geographical_structure` AS `g".$i."` ON `g".($i-1)."`.`parent_ID` = `g".$i."`.`ID`";
	}
	if ($hie !== FALSE)
	{
		$query_string .= " LEFT JOIN `hierarchical_structure` AS `h0` ON `entities`.`hierarchy` = `h0`.`ID`";
		
		// $hie might be on any level - to iterate thgough all necessary levels (because table 'entities' stores only information about the lowest level, not about the whole path), table must be joined with itself, maybe even multiple times (based on number of levels)		
		for ($i = 1; $i <= $hie_from_bottom; $i++)
			$query_string .= " LEFT JOIN `hierarchical_structure` AS `h".$i."` ON `h".($i-1)."`.`parent_ID` = `h".$i."`.`ID`";
	}
	
	$query_string .= " WHERE 
	`entities`.`visibility` = 1";
	if ($geo !== FALSE)
		$query_string .= " AND `g".$geo_from_bottom."`.`ID` = '".$geo."'";
	if ($hie !== FALSE)
		$query_string .= " AND `h".$hie_from_bottom."`.`ID` = '".$hie."'";
		
	$query_string .= "
	ORDER BY 
	`entities`.`name` ASC,
	`entities`.`sub_name` ASC";
	
	$output = array();
	$query = mysqli_query($con, $query_string);
	if ($query)
		while ($row = mysqli_fetch_array($query))
			$output[$row["ID"]] = $row;
	
	return $output;
}

?>