<?php

function draw_all_profiles_tree($type, $parent, $cols = 4)
{
	// recursive function for displaying tree of all entities
	global $colcount, $GS;
	
	if ($type == 'geography')
		$children = get_geo_children($parent["ID"]);
	if ($type == 'hierarchy')
		$children = get_hie_children($parent["ID"]);
		
	if (count($children) > 0) // still digging deeper into structure
	{
		foreach ($children as $child)
		{
			if ($child["level"] == 1) // first level divides geographical or hierarchical structure into columns
			{
				$colcount++;
				echo '</div>';
				if ($colcount % $cols == 1) // new 'line' of columns
					echo '<div class="clear"></div>';
				echo '<div class="element-'.$cols.'">';		
			}
			echo '<div class="ap-'.min(4, $child["level"]).'">'.$child["name"].'</div>'; // display name of tree element and dig deeper
			draw_all_profiles_tree($type, $child, $cols);
		}
	}
	else // found last level of hierarchy, fetching and displaying entities itself
	{
		if ($type == 'geography')
			$entities = get_entities($parent["ID"], FALSE);
		if ($type == 'hierarchy')
			$entities = get_entities(FALSE, $parent["ID"]);
		foreach ($entities as $entity)
			echo '<div class="ap-e"><a href="/profile/'.$entity["ID"].'/'.$GS["newest_year"].'">'.$entity["name"].($entity["sub_name"]?' <span>'.$entity["sub_name"].'</span>':"").'</a></div>';
	}
}

function draw_all_profiles($cols = 4)
{
	// "master" function for displaying tree of all entities based on geographical or hierarchical structure
	global $GS, $colcount;
	$colcount = 0;
	
	$dim = $GS["all_profiles_dimension"];
	echo '<div>';
	
	// run recursive function for displaying the tree
	if ($dim == 'geography')
	{
		$all_elems = reset(get_geos('0')); // start the recursion at zero level
		draw_all_profiles_tree('geography', $all_elems, $cols);
	}
	if ($dim == 'hierarchy')
	{
		$all_elems = reset(get_hies('0')); // start the recursion at zero level
		draw_all_profiles_tree('hierarchy', $all_elems, $cols);
	}
	
	echo '</div><div class="clear"></div>';
}

function draw_tree($type, $parent, $other_dim_all, $cols = 4)
{
	// recursive function for displaying tree of geographical or hierarchical structure
	global $GS, $colcount;
	$max_level = $GS["max_search_".$type."_level_allowed"];

	// find direct children
	if ($type == 'geography')
		$children = get_geo_children($parent["ID"]);
	if ($type == 'hierarchy')
		$children = get_hie_children($parent["ID"]);
	
	// if some children were found and this is not the last level, display each child and run function for each child
	if (count($children) > 0 && $parent["level"] < $max_level)
	{
		foreach ($children as $child)
		{
			if ($child["level"] == 1) // first level divides geographical or hierarchical structure into columns
			{
				$colcount++;
				echo '</div>';
				if ($colcount % $cols == 1) // new 'line' of columns
					echo '<div class="clear"></div>';
				echo '<div class="element-'.$cols.($colcount<=$cols?" first-line":"").'">';		
			}
			if ($child["level"] == $max_level) // only children on the last level are clickable
			{
				if ($type == 'geography')
					echo '<div class="ap-'.min(4, $child["level"]).' pt-e"><a href="/search/spec/'.$child["ID"].'-'.$other_dim_all["ID"].'">'.$child["name"].'</a></div>';
				if ($type == 'hierarchy')
					echo '<div class="ap-'.min(4, $child["level"]).' pt-e"><a href="/search/spec/'.$other_dim_all["ID"].'-'.$child["ID"].'">'.$child["name"].'</a></div>';
			}
			else
				echo '<div class="ap-'.min(4, $child["level"]).'">'.$child["name"].'</div>';
				
			draw_tree($type, $child, $other_dim_all, $cols);
		}
	}
}

?>