// JavaScript Document

var headerHeight = 44; // height of page header

Element.prototype.DOMRemove = function() 
{
	this.parentElement.removeChild(this);
}

if (!Array.prototype.remove)
{
	Array.prototype.remove = function() 
	{
		var what, a = arguments, L = a.length, ax;
		while (L && this.length) {
			what = a[--L];
			while ((ax = this.indexOf(what)) !== -1) 
			{
				this.splice(ax, 1);
			}
		}
		return this;
	};
}

if (!Array.prototype.indexOf)
{
	Array.prototype.indexOf = function(searchElement /*, fromIndex */)
  {
    "use strict";
    if (this === void 0 || this === null)
      throw new TypeError();

    var t = Object(this);
    var len = t.length >>> 0;
    if (len === 0)
      return -1;

    var n = 0;
    if (arguments.length > 0)
    {
      n = Number(arguments[1]);
      if (n !== n)
        n = 0;
      else if (n !== 0 && n !== (1 / 0) && n !== -(1 / 0))
        n = (n > 0 || -1) * Math.floor(Math.abs(n));
    }

    if (n >= len)
      return -1;

    var k = n >= 0
          ? n
          : Math.max(len - Math.abs(n), 0);

    for (; k < len; k++)
    {
      if (k in t && t[k] === searchElement)
        return k;
    }
		
    return -1;
  };
}

function getRequest() 
{
	var req = false;
	try
	{
		// most browsers
		req = new XMLHttpRequest();
	} 
	catch (e)
	{
		// IE
		try
		{
			req = new ActiveXObject("Msxml2.XMLHTTP");
		} 
		catch (e) 
		{
			// try an older version
			try
			{
				req = new ActiveXObject("Microsoft.XMLHTTP");
			} 
			catch (e)
			{
				return false;
			}
		}
	}
	return req;
}

function setCookie(cname, cvalue, exsecs) 
{
	// convert exsecs to time when cookie expires
	var d = new Date();
	d.setTime(d.getTime() + (exsecs*1000));
	var expires = "expires="+d.toUTCString();
	// write cookie
	document.cookie = cname + "=" + cvalue + "; " + expires + "; path=/";
}

function getCookie(cname) 
{
	var name = cname + "=";
	var ca = document.cookie.split(';');
	// iterate through all cookie "elements"
	for (var i=0; i<ca.length; i++) 
	{
		var c = ca[i];
		while (c.charAt(0)==' ') c = c.substring(1);
		if (c.indexOf(name) != -1) return c.substring(name.length,c.length);
	}
	return "";
}

function hide(elementID)
{
	document.getElementById(elementID).style.display = 'none';
}

function show(elementID)
{
	document.getElementById(elementID).style.display = '';
}

function toggle(elementID)
{
	if (document.getElementById(elementID).style.display == '')
		document.getElementById(elementID).style.display = 'none';
	else
		document.getElementById(elementID).style.display = '';
}

function toggleText(elementID, buttonID, textOn, textOff)
{
	if (document.getElementById(elementID).style.display == '')
		document.getElementById(buttonID).innerHTML = textOff;
	else
		document.getElementById(buttonID).innerHTML = textOn;
	toggle(elementID);
}

function getWindowWidth() 
{
	// for compatibility reasons
	
  var myWidth = 0;
  if(typeof(window.innerWidth) == 'number') 
    myWidth = window.innerWidth;
	else if(document.documentElement && (document.documentElement.clientWidth || document.documentElement.clientHeight)) 
    myWidth = document.documentElement.clientWidth;
	else if(document.body && (document.body.clientWidth || document.body.clientHeight)) 
    myWidth = document.body.clientWidth;
	
	return myWidth;
}

function googleChart(rowID, dataString, formatterString, namesString, limit) 
{
	//rowID - type of value chart is created for
	
	var data = new google.visualization.DataTable();
	data.addColumn('number', 'Year');
	
	var minYear = 1000000, maxYear = -1000000;
	
	// since sub_names in names entering namesString are enclosed in <span> tag, we want to remove it
	namesString = namesString.replace('</span>', '');
	namesString = namesString.replace('<span>', ' ');
	var names = namesString.split(";");
	
	// dataString: objects are separated with "#"
	// for each object, year-elements are separated with ";"
	// for each year-element, year and value are separated with ":"
	
	// just parsing dataString into values array
	var elements = dataString.split("#");
	var values = [];
	var years = [];
	for (var i=0; i<elements.length; i++)
	{
		var yearStrings = elements[i].split(";");
		data.addColumn('number', names[i]);
		years[i] = [];
		values[i] = [];
		for (var j=0; j<yearStrings.length; j++)
		{
			var bit = yearStrings[j].split(":");
			var year = parseFloat(bit[0]);
			var value = bit[1];
			if (year < minYear)	minYear = year;
			if (year > maxYear) maxYear = year;
			values[i][year] = value;
		}
	}
	
	// determining width of the chart
	var width = document.getElementById('graph-'+rowID).clientWidth;
	width = Math.round(width*0.91 - 160);
	var yearCount = maxYear - minYear + 1;
	if (yearCount >= Math.floor(width / 50)) chartWidth = '80%';
		else chartWidth = 50*yearCount;
	
	// parsing formatterString into ICU pattern
	// formatterString: [google locale]#~[decimal places]#~[suffix]
	var formatterElements = formatterString.split("#~");
	var formatterPattern = '#,###';
	if (formatterElements[1] > 0)
	{
		formatterPattern += '.';
		for (var i=0; i<formatterElements[1]; i++)
			formatterPattern += '#';
	}
	formatterPattern += formatterElements[2];
	
	// storing data from values array into chart itself. Replacing missing values with null and dividing percentages with 100
	for (var i = minYear; i <= maxYear; i++)
	{
		var dataArray = [i];
		for (var j = 0; j < elements.length; j++)
		{
			if (typeof(values[j][i]) === 'undefined' || values[j][i] == 'n/a')
				dataArray[j+1] = null;
			else
				dataArray[j+1] = parseFloat(values[j][i]);
			var trimmedSuffix = formatterElements[2].replace(/\s+/g,"");
			if ((dataArray[j+1] != null) && (trimmedSuffix == '%'))
				dataArray[j+1] = dataArray[j+1]/100;
		}
		data.addRow(dataArray);
	}
	
	// if chart is drawn in "profile" page - only one line is drawn, so line color is specified
	if (limit == 1)
 	{
		var chartOptions = {
			hAxis: {format: '####', allowContainerBoundaryTextCufoff: true, minValue: minYear-0.001, maxValue: maxYear+0.001, gridlines: {color: '#D0D0D0', count: (maxYear - minYear + 1)}},
			vAxis: {format: formatterPattern, gridlines: {color: '#D0D0D0'}},
			fontName: 'Open Sans',
			fontSize: 11,
			fontWeight: 600,
			locale: formatterElements[0],
			legend: {position: 'bottom', textStyle:{fontSize: 11}},
			backgroundColor: {fill:'transparent'},
			series: {0:{lineWidth: 2,	pointSize: 5, color: '#91791a'}},
			height: 250,
			chartArea: {left: 150, top: 30, width: chartWidth, height: 150}
		};
 	}
 
	// if chart is drawn in "comparison" page - any number of lines can be drawn, so line color will not be specified
 	if (limit == 0)
	{
		var chartOptions = {
			hAxis: {format: '####', allowContainerBoundaryTextCufoff: true, minValue: minYear-0.001, maxValue: maxYear+0.001, gridlines: {color: '#D0D0D0', count: (maxYear - minYear + 1)}},
			vAxis: {format: formatterPattern, gridlines: {color: '#D0D0D0'}},
			fontName: 'Open Sans',
			fontSize: 11,
			fontWeight: 600,
			locale: formatterElements[0],
			legend: {position: 'bottom', textStyle:{fontSize: 11}},
			backgroundColor: {fill:'transparent'},
			lineWidth: 2,
			pointSize: 5,
			height: 250,
			chartArea: {left: 150, top: 30, width: chartWidth, height: 150}
		};
	}
	
	var formatter = new google.visualization.NumberFormat({pattern: formatterPattern});	
			
	// format all series to desired number format
	for (var i=1; i<=elements.length; i++)
		formatter.format(data, i);
	
	// draw chart
	var chart = new google.visualization.LineChart(document.getElementById('graph-'+rowID));
	chart.draw(data, chartOptions);
}

function drawChart(rowID, objectsID, formatter, names, limit, PWText)
{
	// fetch chart data and call function to draw them
	// rowID - type of values chart will be drawn for
	// objectsID - list of objects chart will be drawn for
	// formatter, names, limit - passed to googleChart function
	// PWText - text shown while data are fetched
	
	var ajax = getRequest();
	ajax.onreadystatechange = function()
	{
		if(ajax.readyState == 4)
		{
			var result = ajax.responseText;
			googleChart(rowID, result, formatter, names, limit);
			document.getElementById('i-'+rowID).className = 'i-minus';
			var content = document.getElementById('n-'+rowID).innerHTML;
			document.getElementById('n-'+rowID).innerHTML = content.replace('<span>'+PWText+'...</span>', '');
		}
	}
	ajax.open("GET", "/include/ajax/getChartData.php?dt="+rowID+"&o="+objectsID);
	ajax.send(null);
}

function drawInfo(rowID, PWText, type)
{
	// fetch explanation for selected values and display them
	// rowID - type of values chart will be drawn for
	// type - if values are numbers "n" or text "t".
	var ajax = getRequest();
	ajax.onreadystatechange = function()
	{
		if(ajax.readyState == 4)
		{
			var result = ajax.responseText;
			if (result != 'n/a')
				document.getElementById('exp-'+rowID).innerHTML = '<div>'+result+'</div>';
			var content = document.getElementById('n-'+rowID).innerHTML;
			// if values are text and not numbers, no chart will be drawn, request is finished and therefore hide PWText
			if (type != 'n')
				document.getElementById('n-'+rowID).innerHTML = content.replace('<span>'+PWText+'...</span>', '');
		}
	}
	ajax.open("GET", "/include/ajax/getInfo.php?dt="+rowID);
	ajax.send(null);
}

function toggleMoreInfo(rowID, objectsID, formatter, names, limit, type, PWText)
{
	// main function for toggling chart and explanation for each row in profile or comparison
	
	var graphDiv = document.getElementById('graph-'+rowID); // chart
	var expDiv = document.getElementById('exp-'+rowID); // explanation
	if (graphDiv.innerHTML != '' || expDiv.innerHTML != '') // if chart or explanation is already displayed, 'hide' it
	{
		graphDiv.innerHTML = '';
		expDiv.innerHTML = '';
		document.getElementById('i-'+rowID).className = 'i-plus';
	}
	else // start request, therefore show PWtext
	{
		var content = document.getElementById('n-'+rowID).innerHTML;
		document.getElementById('n-'+rowID).innerHTML = content + '<span>'+PWText+'...</span>';
		drawInfo(rowID, PWText, type); // draw explanation
		if (type == 'n') // if values are numbers, draw chart
			drawChart(rowID, objectsID, formatter, names, limit, PWText);
	}
}

function switchNav(type)
{
	// switch between 'geography' and 'hierarchy' tree in left navigation pane in "profile" page
	if (type == 'geo')
	{
		document.getElementById('li-nav-geo').className = '';
		document.getElementById('li-nav-hie').className = 'unselected';	
		show('nav-geo');
		hide('nav-hie');
	}
	if (type == 'hie')
	{
		document.getElementById('li-nav-geo').className = 'unselected';
		document.getElementById('li-nav-hie').className = '';		
		show('nav-hie');
		hide('nav-geo');
	}
}

function toggleNav()
{
	// show or hide entire left navigation pane in "profile" page
	toggle("nav");
	if (document.getElementById("nav").style.display == '')
	{
		document.getElementById("nav-toggle").className = 'visible';
		document.getElementById('nav-wrapper').style.width = '344px';
	}
	else
	{
		document.getElementById("nav-toggle").className = 'hidden';
		document.getElementById('nav-wrapper').style.width = '0px';
	}
}

function toggleBP(textHide, textShow)
{
	// show or hide basic properties in "profile" page.
	// whenever google map is resized, 'resize' event must be triggered to correctly display new map

	var center = map.getCenter();
	toggleText('profile-head', 'profile-head-toggle-button', textHide, textShow);
	google.maps.event.trigger(map, 'resize')
	map.setCenter(center);
}

function showCNWindow(position, objectsString, years)
{
	// function for showing window in "comparison" page for adding new object
	// immediately after window is shown, "top level obejct" (with geo level == 0 and hie level == 0) can be added to comparison
	
	// position - position among compared objects
	// objectsString - objects currently compared
	// years - years selected for comparison
	show('cn-window');
	
	// determining which button was pressed
	if (objectsString !== '')
	{
		var objects = objectsString.split(',');
		if (position <= objects.length)
			whereID = 'changeButton-' + position;
		else
			whereID = 'changeButton-0';
	}
	else
		whereID = 'changeButton-0';
		
	// position for new window
	var whereRect = document.getElementById(whereID).getBoundingClientRect();
	var windowRect = document.getElementById('cn-window').getBoundingClientRect();
	var windowWidth = windowRect.right - windowRect.left;
	document.getElementById('cn-window').style.left = whereRect.right - windowWidth + 'px';
	document.getElementById('cn-window').style.top = whereRect.bottom + document.body.scrollTop + 20 - headerHeight - 1 + 'px';
	document.getElementById("pos-dummy").innerHTML = position;

	// geography and hierarchy criteria
	var geoSel = document.getElementById("geo-select-1");
	var geo = geoSel.options[geoSel.selectedIndex].value;
	var hieSel = document.getElementById("hie-select-1");
	var hie = hieSel.options[hieSel.selectedIndex].value;
	var objString = geo + '-' + hie;
	
	// adding new object to specific position
	if (objectsString !== '')
	{
		var oldObject = objects[parseInt(position) - 1];
		objects[parseInt(position) - 1] = objString;
	}
	else
		objects = [objString];
	
	var newObjectsString = objects.join(',');

	if (position >= objects.length) // adding new object
		document.getElementById('cnb-add').onclick = function() {addToBasket(objString); window.location.href='/comparison/'+newObjectsString+'/'+years;};
	else
	{
		if (objectsString !== '') // changing one object to another
			document.getElementById('cnb-add').onclick = function() {removeFromBasket(oldObject); addToBasket(objString); window.location.href='/comparison/'+newObjectsString+'/'+years;};
	}
}

function toggleSelWindow(windowID, triggerID, columns, criteria, years, display)
{
	// function for showing or hiding window in "rankings" page to select geography or hierarchy criteria
	// windowID - ID of toggled window
	// triggerID - ID of button pressed
	// columns, criteria, years - columns, criteria and years displayed in ranking
	// display - string containing displaying parameters - pagination, column for sorting and sorting order
	toggle(windowID);
	
	// position for new window
	var whereRect = document.getElementById(triggerID).getBoundingClientRect();
	var windowRect = document.getElementById(windowID).getBoundingClientRect();
	var wrapperRect = document.getElementById('rankings-content-wrapper').getBoundingClientRect();
	var wrapperWidth = wrapperRect.right - wrapperRect.left;
	var whereWidth = whereRect.right - whereRect.left;
	document.getElementById(windowID).style.left = whereRect.right + 20 + 'px';
	document.getElementById(windowID).style.top = whereRect.top + document.body.scrollTop - headerHeight - 1 + 'px';
	document.getElementById(windowID).style.maxWidth = wrapperWidth - whereWidth - 102 + 'px';
	
	// get all geography and hierarchy criteria currently used for ranking
	if (windowID == 'geo-sel' || windowID == 'hie-sel')
	{
		var criteria_parts = criteria.split("-");
		var geos = criteria_parts[0];
		var hies = criteria_parts[1];
	}
	
	// new geography criterion is added
	if (windowID == 'geo-sel')
	{
		var geoSel = document.getElementById("geo-select-1");
		var geo = geoSel.options[geoSel.selectedIndex].value;
		geos = add_to_list(geos, geo); // add to list of criteria
		document.getElementById('geo-cnb-add').onclick = function() {window.location.href='/rankings/'+columns+'/'+geos+'-'+hies+'/'+years+'/'+display};
	}
	
	// new hierarchy criterion is added
	if (windowID == 'hie-sel')
	{
		var hieSel = document.getElementById("hie-select-1");
		var hie = hieSel.options[hieSel.selectedIndex].value;
		hies = add_to_list(hies, hie); // add to list of criteria
		document.getElementById('hie-cnb-add').onclick = function() {window.location.href='/rankings/'+columns+'/'+geos+'-'+hies+'/'+years+'/'+display};
	}
}

function setEmptyBasket()
{
	// function for adding text i_empty_basket to basket when basket is empty
	
	var ajax = getRequest();
	var name = "i_empty_basket"; // "name" of empty basket text in the database
	
	ajax.onreadystatechange = function()
	{
		if(ajax.readyState == 4)
		{
			var result = ajax.responseText;
			document.getElementById('basket-window').innerHTML = '<div class="info-area">'+result+'</div>';
		}
	}
	ajax.open("GET", "/include/ajax/getText.php?name="+name); // get text from the database
	ajax.send(null);	
}

function doSelect(type, level, maxLevel, objectsString, years)
{
	// function for selecting geography, hierarchy and entity in cnWindow dropdown boxes
	// type - geo, hie or entity
	// level - geography or hierarchy level
	// maxLevel - maximum geography or hierarchy level
	// objectsString - current objects in comparison
	// years selected for comparison
	
	var position = document.getElementById('pos-dummy').innerHTML; // which object is changed / added
	var allElement = document.getElementById('entity-select');
	var allText =  allElement.options[0].innerHTML; // initial text for "all geography and hierarchy"	
	
	var objString, objects, geoPart, hiePart, parent;
	var gi = 1, hi = 1;
	
	if (type == 'geo' || type == 'hie')
	{		
		// resetting dropdown menus and reading selected values
		// if dropdown for current level is visible or iterating through other dimension (geo if type == 'hie' and conversely), get value of dropdown select, else 'reset' selected value
		while (document.getElementById('geo-select-'+gi))
		{
			var geoSel = document.getElementById("geo-select-"+gi);
			if (gi <= level || type == 'hie')
			{
				var geo = geoSel.options[geoSel.selectedIndex].value;
				if (geo != "#~") geoPart = geo;
			}
			else
			{
				geoSel.value = '#~';
				document.getElementById("geo-div-"+gi).style.display = 'none';
			}
			gi++;
		}
		// the same as before but for another dimension
		while (document.getElementById('hie-select-'+hi))
		{
			var hieSel = document.getElementById("hie-select-"+hi);
			if (hi <= level || type == 'geo')
			{
				var hie = hieSel.options[hieSel.selectedIndex].value;
				if (hie != "#~") hiePart = hie;
			}
			else
			{
				hieSel.value = '#~';
				document.getElementById("hie-div-"+hi).style.display = 'none';
			}
			hi++;
		}

		// object that will be added to current list of compared objects		
		objString = geoPart+'-'+hiePart;
		
		// find "parent" for options available in dropdown for next level
		if (type == 'geo' && level < maxLevel) parent = geoPart;
		if (type == 'hie' && level < maxLevel) parent = hiePart;
		if (level == maxLevel) parent = objString;
		
		if (level < maxLevel)
		{
			// if higher level is available, display dropdown for that level			
			document.getElementById(type+"-div-"+(level+1)).style.display = '';
			document.getElementById("entity-div").style.display = 'none';
			var currentSel = document.getElementById(type + "-select-" + (level+1));			
		}
		else
		{
			// display dropdown for entity selection
			document.getElementById("entity-div").style.display = '';
			var currentSel = document.getElementById("entity-select");
		}
		
		var ajax = getRequest();
		ajax.onreadystatechange = function()
		{
			if(ajax.readyState == 4)
			{
				var result = ajax.responseText;
				
				currentSel.innerHTML = '';

				// 'null' option				
				var option = document.createElement('option');
				option.value = "#~";
				option.innerHTML = allText;
				currentSel.appendChild(option);
				
				// parsing result containint all avaibable options for next dropdown menu
				if (result != "#~")
				{
					// display all child elements as options for next dropDown menu
					var optionValues = result.split("||");
					for (var i = 0; i < optionValues.length; i++)
					{
						var partsString = optionValues[i];
						var parts = partsString.split("|");
						var option = document.createElement('option');
						option.value = parts[0];
						option.innerHTML = parts[1];
						currentSel.appendChild(option);
					}
				}
			}
		}
		if (level < maxLevel)
			// get children geography or hierarchy elements belonging to their parent
			ajax.open("GET", "/include/ajax/getCNOptions.php?type="+type+"&parent="+parent);
		else
			// get entities belonging to their parent geography and hierarchy
			ajax.open("GET", "/include/ajax/getCNOptions.php?type=entity&parent="+parent);
		ajax.send(null);	

	}
	
	// determining which object should be added to current list of objects
	if (type == 'entity')
	{
		var entitySel = document.getElementById("entity-select");
		// discard original objString defined as 'geo-hie', entity will be added
		objString = entitySel.options[entitySel.selectedIndex].value;
	}

	// adding new object to list of current objects at the desired position
	if (objectsString !== '')
	{
		objects = objectsString.split(',');
		var oldObject = objects[parseInt(position) - 1];
		objects[parseInt(position) - 1] = objString;
	}
	else
		objects = [objString];
	var newObjectsString = objects.join(',');

	
	if (position > objects.length) // adding new object
		document.getElementById('cnb-add').onclick = function() {addToBasket(objString); window.location.href='/comparison/'+newObjectsString+'/'+years;};
	else // changing one object for another
	{
		if (objectsString !== '')
			document.getElementById('cnb-add').onclick = function() {removeFromBasket(oldObject); addToBasket(objString); window.location.href='/comparison/'+newObjectsString+'/'+years;};
	}
}

function doRankSelect(type, level, maxLevel, columns, criteria, years, display)
{
	// function for selecting geography and hierarchy criteria in dropdown menus in "rankings" page
	// type - geo, hie or entity
	// level - geography or hierarchy level
	// maxLevel - maximum geography or hierarchy level
	// columns, criteria, years - columns, criteria and years displayed in ranking
	// display - string containing displaying parameters - pagination, column for sorting and sorting order

	var allText = '(' + document.getElementById('alltext').innerHTML + ')';	// initial text for "all geography or hierarchy"	
	// get geo and hie criteria
	var criteria_parts = criteria.split("-");
	var geos = criteria_parts[0];
	var hies = criteria_parts[1];
	
	var objString, objects, geoPart, hiePart;
	var lev = 1;
	
	if (type == 'geo')
	{
		// resetting dropdown menus and reading selected values
		// if dropdown for current level is visible, get value of dropdown select, else 'reset' selected value
		while (document.getElementById('geo-select-'+lev))
		{
			var geoSel = document.getElementById("geo-select-"+lev);
			if (lev <= level)
			{
				var geo = geoSel.options[geoSel.selectedIndex].value;
				if (geo != "#~") geoPart = geo;
			}
			else
			{
				geoSel.value = '#~';
				document.getElementById("geo-div-"+lev).style.display = 'none';
			}
			lev++;
		}

		// if current level is not the last, display next level
		if (level < maxLevel)
		{
			document.getElementById("geo-div-"+(level+1)).style.display = '';
			var currentSel = document.getElementById("geo-select-" + (level+1));			
		}
	}
	
	// the same as above but for another dimension
	if (type == 'hie')
	{
		while (document.getElementById('hie-select-'+lev))
		{
			var hieSel = document.getElementById("hie-select-"+lev);
			if (lev <= level)
			{
				var hie = hieSel.options[hieSel.selectedIndex].value;
				if (hie != "#~") hiePart = hie;
			}
			else
			{
				hieSel.value = '#~';
				document.getElementById("hie-div-"+lev).style.display = 'none';
			}
			lev++;
		}

		if (level < maxLevel)
		{
			document.getElementById("hie-div-"+(level+1)).style.display = '';
			var currentSel = document.getElementById("hie-select-" + (level+1));			
		}
	}
		
	var ajax = getRequest();
	ajax.onreadystatechange = function()
	{
		if(ajax.readyState == 4)
		{
			var result = ajax.responseText;
			
			currentSel.innerHTML = '';
			
			// 'initial' option
			var option = document.createElement('option');
			option.value = "#~";
			option.innerHTML = allText;
			currentSel.appendChild(option);
			
			// parsing result containing all avaibable options for next dropdown menu
			if (result != "#~")
			{
				// display all child elements as options for next dropDown menu
				var optionValues = result.split("||");
				for (var i = 0; i < optionValues.length; i++)
				{
					var partsString = optionValues[i];
					var parts = partsString.split("|");
					var option = document.createElement('option');
					option.value = parts[0];
					option.innerHTML = parts[1];
					currentSel.appendChild(option);
				}
			}
		}
	}

	if (type == 'geo')
	{
 		// if current level is not the last, get child geography elements for current geography
 		if (level < maxLevel)
		{
			ajax.open("GET", "/include/ajax/getCNOptions.php?type=geo&parent="+geoPart);
			ajax.send(null);	
		}
		
		// add selected geography to the list of geography criteria
		geos = add_to_list(geos, geoPart);
		// add onclick event that will display ranking with new set of geography criteria
		document.getElementById('geo-cnb-add').onclick = function() {window.location.href='/rankings/'+columns+'/'+geos+'-'+hies+'/'+years+'/'+display;};
	}
	
	// the same as above but for another dimension
	if (type == 'hie')
	{
		if (level < maxLevel)
		{
			ajax.open("GET", "/include/ajax/getCNOptions.php?type=hie&parent="+hiePart);
			ajax.send(null);	
		}

		hies = add_to_list(hies, hiePart);
		document.getElementById('hie-cnb-add').onclick = function() {window.location.href='/rankings/'+columns+'/'+geos+'-'+hies+'/'+years+'/'+display;};
	}
	
}

function doColSelect(level, columns, criteria, years, display)
{
	// function for columns (data, indicators, ratings) in dropdown menus in "rankings" page
	// level - column level
	// columns, criteria, years - columns, criteria and years displayed in ranking
	// display - string containing displaying parameters - pagination, column for sorting and sorting order

	var SCText = '(' + document.getElementById('selectcolumntext').innerHTML + ')';	// initial text for "select column"	

	var objString, objects, colPart;
	var lev = -1;
	var selected;
	var type;
	
	// resetting dropdown menus and reading selected values
	// if dropdown for current level is visible, get value of dropdown select, else 'reset' selected value and disable adding this column to list of displayed columns
	while (document.getElementById('col-select-'+lev))
	{
		var colSel = document.getElementById('col-select-'+lev);
		if (lev <= level)
		{
			var col = colSel.options[colSel.selectedIndex].value;
			colPart = col;
			if (lev == -1) type = col; // not actually selecting which column to add, but which type of column will be chosen (data, indicator or rating)
		}
		else
		{
			colSel.value = '#~';
			document.getElementById("col-div-"+lev).style.display = 'none';
			document.getElementById('col-cnb-add-'+lev).className = 'button b-normal b-yellow-deactivated';				
			document.getElementById('col-cnb-add-'+lev).onclick = '';				
		}
		lev++;
	}
	
	if (level == -1) colPart = ''; // no column is selected yet
	
	var ajax = getRequest();
	ajax.onreadystatechange = function()
	{
		if(ajax.readyState == 4)
		{
			var result = ajax.responseText;

			if (result != "#~") // there are any children elements for specified value type
			{
				if (colPart != "#~") // some 'real' option is selected
				{
					document.getElementById("col-div-"+(level+1)).style.display = '';
					var currentSel = document.getElementById("col-select-" + (level+1));			
	
					currentSel.innerHTML = '';
					
					// 'initial' option
					var option = document.createElement('option');
					option.value = "#~";
					option.innerHTML = SCText;
					currentSel.appendChild(option);
					
					// parsing result containing all avaibable options for next dropdown menu as well as information whether the column contains data or is only parent to another columns
					var optionValues = result.split("||");
					var hasData = optionValues[0];
					
					// if column has data, make it possible to add the column to the list of columns displayed in ranking 
					if (hasData == 1)
					{
						columns = add_to_list(columns, type.substr(0, 1) + colPart);
						document.getElementById('col-cnb-add-'+level).onclick = function() {window.location.href='/rankings/'+columns+'/'+criteria+'/'+years+'/'+display;};
						document.getElementById('col-cnb-add-'+level).className = 'button b-normal b-yellow';
					}
					
					// display all child elements as options for next dropDown menu
					for (var i = 1; i < optionValues.length; i++)
					{
						var partsString = optionValues[i];
						var parts = partsString.split("|");
						var option = document.createElement('option');
						option.value = parts[0];
						option.innerHTML = parts[1];
						currentSel.appendChild(option);
					}
				}
				else // none option is selected, therefore option (column) currently selected cannot be added to list of columns displayed in ranking
				{
					document.getElementById('col-cnb-add-'+level).className = 'button b-normal b-yellow-deactivated';				
					document.getElementById('col-cnb-add-'+level).onclick = '';				
				}
			}
			else // there ist not any child elements for specified value type
			{
				if (colPart != '#~' && level > -1) // some 'real' option (column) is selected
				{
					// make it possible to add the column to the list of columns displayed in ranking
					columns = add_to_list(columns, type.substr(0, 1) + colPart);
					document.getElementById('col-cnb-add-'+level).onclick = function() {window.location.href='/rankings/'+columns+'/'+criteria+'/'+years+'/'+display;};
					document.getElementById('col-cnb-add-'+level).className = 'button b-normal b-yellow';
				}
				else // none option is selected, therefore option (column) currently selected cannot be added to list of columns displayed in ranking
					if (level > -1)
					{
						document.getElementById('col-cnb-add-'+level).className = 'button b-normal b-yellow-deactivated';
						document.getElementById('col-cnb-add-'+level).onclick = '';				
					}
			}
		}
	}
	
	ajax.open("GET", "/include/ajax/getCNOptions.php?type="+type+"&parent="+colPart);
	ajax.send(null);	

}

function changeMap(element, type, anotherValue)
{
	// show "map" page with new geography and hierarchy selected
	
	var value = element.options[element.selectedIndex].value;
		
	if (type == 'geo')
		window.location.href = '/map/'+value+'-'+anotherValue;
	if (type == 'hie')
		window.location.href = '/map/'+anotherValue+'-'+value;
}

function get_toc_class()
{
	// fix table of contents for "text" pages to top or to bottom of 
	
	// height of entire page
	var bodyHeight = document.getElementById('body-wrapper').offsetHeight;
	
	// scrolled position from top
	var scrollTop = 0;
	if (document.body.scrollTop > 0) scrollTop = document.body.scrollTop;
	if (document.documentElement.scrollTop > 0) scrollTop = document.documentElement.scrollTop;
	
	if (scrollTop > 0)
	{
		if (scrollTop >= bodyHeight - document.getElementById('toc').offsetHeight - headerHeight) // scrolled too much
			document.getElementById('toc').className = "toc toc-bottomfixed"; // pin to bottom
		else
			document.getElementById('toc').className = "toc toc-fixed"; // pin to top
	}
	else
		document.getElementById('toc').className = "toc"; // do not pin anywhere
		
}

function doSearch(elID)
{
	// trigger search based on value of elID text field
	
	var searchString = document.getElementById(elID).value;
	window.location.href = '/search/'+searchString;
}

function list_size(list)
{
	// get number of elements in list
	// list is string of elements separated by comma
	
	if (list.length == 0) return 0;
	var list_elements = list.split(",");
	return list_elements.length;
}

function in_list(list, element)
{
	// return position of element in list
	// list is string of elements separated by comma
	
	var list_elements = list.split(",");
	var position = list_elements.indexOf(element);
	if (position >= 0) 
		return position; 
	else 
		return -1;	
}

function add_to_list(list, element)
{
	// add element to the end of list, if list does not already contain element
	// list is string of elements separated by comma
	
	var list_elements;
	
	if (list)
		list_elements = list.split(",");
	else
		list_elements = [];

	if (in_list(list, element) < 0)	
		list_elements.push(element);
		
	return list_elements.join(",");
}

function remove_from_list(list, element)
{
	// remove element from list, if list does contain element
	// list is string of elements separated by comma

	var list_elements;
	
	if (list)
		list_elements = list.split(",");
	else
		list_elements = [];

	if (in_list(list, element) >= 0)
		list_elements.remove(element);
		
	return list_elements.join(",");	
}

function removeFromBasket(element)
{
	// function for removing element from basket
	var currentList = getCookie('c_entities'); // get list
	if (in_list(currentList, element) >= 0) // if element is in basket
	{
		// set new list of basket elements
		currentList = remove_from_list(currentList, element);
		setCookie("c_entities", currentList, 28*24*60*60);
		location.reload();
	}
}

function addToBasket(element, name)
{
	// function for adding elements to basket
	var currentList = getCookie('c_entities'); // get list
	if (in_list(currentList, element) < 0) // if element is not in basket
	{
		// set new list of basket elements
		currentList = add_to_list(currentList, element);
		setCookie("c_entities", currentList, 28*24*60*60);
		location.reload();
	}
}