<?php
	require_once('include/connection.php'); // mysql connection
	require_once('include/preload.php'); // texts and global settings

	// required only for header -->
	require_once('include/tables.php'); // basic tables with data structure
	require_once('include/support.php'); // support functions
	require_once('include/taxonomy.php'); // operating with data and its structure

	require_once('structure/header.php');

	if ($GS["caching_enabled"])
		require_once('structure/caching-header.php'); // all content generated after main menu can be cached and generated from cache

?>

<script type="text/javascript" src="https://maps.googleapis.com/maps/api/js?key=AIzaSyAxuAStM5bxqH7tzfGstbgqxIhxfOMdxMU&sensor=false"></script>
<script type="text/javascript" src="/js/markerclusterer.js"></script>

<?php
	if (isset($_GET["objects"])) $objects = $_GET["objects"]; else $objects = NULL;
	if (!preg_match("/^[0-9a-zA-Z-]+$/", $objects)) $objects = NULL;
	
	// calculate center of map based on entities shown on the map
	if (is_aggregate($objects)) // geo or hie is specified
	{
		$parts = explode("-", $objects);
		$geo = $parts[0];
		$hie = $parts[1];
	}
	else // all entities will be shown
	{
		$geo0 = get_geos('0');
		$hie0 = get_hies('0');
		reset($geo0);
		reset($hie0);
		$geo = key($geo0);
		$hie = key($hie0);
	}
	$geo_level = get_geo_level($geo.'-'.$hie);
	$hie_level = get_hie_level($geo.'-'.$hie);

	$entities = get_entities($geo, $hie);
	$average_latitude = 0;
	$average_longitude = 0;
	
	// calculation
	$c = 0;
	foreach ($entities as $entity)
	{
		$average_latitude += $entity["latitude"];
		$average_longitude += $entity["longitude"];
		$c++;
	}
	$average_latitude = $average_latitude / $c;
	$average_longitude = $average_longitude / $c;

	// display google map based on calculated center and all shown entities, using markerClusterer to avoid complicated map    
	echo '
	<script type="text/javascript">
		
	  var map
		var markers = [];
    function initialize() 
		{
      var mapOptions = 
			{
        center: new google.maps.LatLng('.$average_latitude.', '.$average_longitude.'),
        zoom: '.$GS["entities_map_zoom"].',
        minZoom: 0
      };
      map = new google.maps.Map(document.getElementById("entities-map-canvas"),  mapOptions);
	';

	// adding entities to map
	foreach ($entities as $entity)
	{	
		echo("var marker".$entity["ID"]." = new google.maps.Marker({position: new google.maps.LatLng(".$entity["latitude"].",".$entity["longitude"]."),	url: '/profile/".$entity["ID"]."/".$GS["newest_year"]."', map: map,	title:'".$entity["name"].(' '.$entity["sub_name"]?' ('.$entity["sub_name"].') ':'')."'});\n");
		echo("google.maps.event.addListener(marker".$entity["ID"].", 'click', function() {window.location.href = marker".$entity["ID"].".url;});\n");
		echo("markers.push(marker".$entity["ID"].");\n");
	}

	// cluster them and load map on onLoad		
	echo '
			var markerCluster = new MarkerClusterer(map, markers, {gridSize: '.$GS["marker_clusterer_grid_size"].'});
		}
		
		google.maps.event.addDomListener(window, "load", initialize);	
		
	</script>';

?>
	
<div id="entities-map-canvas"></div>

<div id="entities-selector-wrapper">
	<div id="entities-selector-content">
  	<div id="entities-selector">

<?php
	
	// displaying dropDown menus based on selected geography and heirarchy

	$geos = get_geos('1');
	$hies = get_hies('1');
	
	$geo_bread = get_geo_bread($geo.'-'.$hie);
	$geo_bread_names = get_geo_bread_names($geo.'-'.$hie);
	$hie_bread = get_hie_bread($geo.'-'.$hie);
	$hie_bread_names = get_hie_bread_names($geo.'-'.$hie);
	
	echo '<div class="es-element-wrapper es-first">';
	for ($i = 1; $i <= min($geo_level + 1, $max_geo_level); $i++) // display only those menus that should be displayed based on level of geography selected
	{
		echo '<div id="geo-div-'.$i.'">';
		echo '<select class="es-select" id="geo-select-'.$i.'" name="geo-select-'.$i.'" onchange="changeMap(this, \'geo\', \''.$hie.'\')">'; // change map when selected option is changed
		$children = get_geo_children($geo_bread[$i-1]);
		$text = '('.$T["all"].' '.$geo_list_table[$i]["text_multi"].')';
		echo '<option value = "'.$geo_bread[$i-1].'">'.$text.'</option>'; // display 'all' option for selected level
		foreach ($children as $child) // draw options with children of current geography selected
			echo '<option value = "'.$child["ID"].'"'.($child["ID"] == $geo_bread[$i]?" selected":"").'>'.$child["name"].'</option>';
		echo '</select>';
		echo '</div>';
	}
	echo '</div>';
	
	// the same as above but for another dimension	
	echo '<div class="es-element-wrapper">';
	for ($i = 1; $i <= min($hie_level + 1, $max_hie_level); $i++)
	{
		echo '<div id="hie-div-'.$i.'">';
		echo '<select class="es-select" id="hie-select-'.$i.'" name="hie-select-'.$i.'" onchange="changeMap(this, \'hie\', \''.$geo.'\')">';
		$children = get_hie_children($hie_bread[$i-1]);
		$text = '('.$T["all"].' '.$hie_list_table[$i]["text_multi"].')';
		echo '<option value = "'.$hie_bread[$i-1].'">'.$text.'</option>';
		foreach ($children as $child)
			echo '<option value = "'.$child["ID"].'"'.($child["ID"] == $hie_bread[$i]?" selected":"").'>'.$child["name"].'</option>';
		echo '</select>';
		echo '</div>';
	}
	echo '</div>';
	
	echo '<div class="clear"></div>';
	
?>
		</div>
	</div>
</div>

<script type="text/javascript">

	function resizeMap()
	{
		var w = window,
				d = document,
				e = d.documentElement,
				g = d.getElementsByTagName("body")[0],
				x = w.innerWidth  || e.clientWidth  || g.clientWidth,
				y = w.innerHeight || e.clientHeight || g.clientHeight;
		
		document.getElementById("entities-map-canvas").style.height = (y - headerHeight - 1) + "px";
	}

  var w = window,
      d = document,
      e = d.documentElement,
      g = d.getElementsByTagName("body")[0],
      x = w.innerWidth  || e.clientWidth  || g.clientWidth,
      y = w.innerHeight || e.clientHeight || g.clientHeight;
  
  document.getElementById("entities-map-canvas").style.height = (y - headerHeight - 1) + "px";
  window.addEventListener("resize", resizeMap);		
  
</script>

<?php
	require_once('structure/footer.php');

	if ($GS["caching_enabled"])
		require_once('structure/caching-footer.php');
?>