<?php
	require_once('include/connection.php'); // mysql connection
	require_once('include/preload.php'); // texts and global settings

	require_once('include/tables.php'); // basic tables with data structure
	require_once('include/support.php'); // support functions
	require_once('include/format.php'); // formatting and displaying text and data
	require_once('include/taxonomy.php'); // operating with data and its structure
	require_once('include/values.php'); // getting values from tables
	require_once('include/ui.php'); // displaying values in profiles, comparison rankings
	require_once('include/trees.php'); // dealing with displaying 'trees' of all entities or while geography or hierarchy structure
	require_once('include/pages.php'); // dealing with text (non-data) pages

	require_once('structure/header.php');

	$PAGE = "profile";// global variable used in functions for displaying values to determine how values should be displayed	
?>

	<script type="text/javascript" src="/js/jquery-1.11.1.min.js"></script>
  <script type="text/javascript" src="/js/tipped.js"></script>

  <script type="text/javascript" 
  	src="https://www.google.com/jsapi?autoload=
    	{
        'modules':
        [{
          'name':'visualization',
          'version':'1',
          'packages':['corechart']
        }]
      }">
  </script>

	<script type="text/javascript">
		// initialize tooltips
    $(document).ready(function() {
      Tipped.create('.i-disclaimer', {fadeIn: 100, fadeOut: 100, behavior: 'hide'});
      Tipped.create('.value', {fadeIn: 100, fadeOut: 100, behavior: 'hide'});
    });
  </script>
          
<?php
	// get objects and years to compare
	if (isset($_GET["objects"])) $objects_string = $_GET["objects"]; else $objects_string = NULL;
	if (!preg_match("/^[0-9a-zA-Z-]+$/", $objects_string)) $objects_string = NULL;

	if (isset($_GET["years"])) $years = $_GET["years"]; else $years = NULL;
	if (!preg_match("/^[0-9]+$/", $years)) $years = NULL;

	if (!is_numeric($years)) $years = $GS["newest_year"];
	
	$years_a = parse_years($years);
	$raw_objects = parse_objects($objects_string);
	
	$objects = array();
	foreach ($raw_objects as $raw_object)
		if (is_entity($raw_object) || is_aggregate($raw_object))
			$objects[] = $raw_object;
		
 	$objects = array_slice($objects, 0, 1);
	$obj_count = count($objects);
	
	// initialize variables
	$data = array();
	$indicators = array();
	$ratings = array();
	$disc_data = array();
	$disc_indicators = array();
	$disc_ratings = array();
	$names = array();
	$geo_a = array();
	$hie_a = array();
	
	// get basic information
	foreach ($objects as $obj_string)
	{
		$is_entity = is_entity($obj_string);
		$is_aggregate = is_aggregate($obj_string);
		$names[] = get_obj_name($obj_string);
		
		$geo = get_geo($obj_string);
		$geo_a[] = $geo;
		$hie = get_hie($obj_string);
		$hie_a[] = $hie;
		$geo_level = get_geo_level($obj_string);
		$hie_level = get_hie_level($obj_string);
	}
	
	$names_string = implode(";", $names);
	
	if ($obj_count > 0) // is anything to show
	{
		$main_object = $objects[0];
			
		// get geography and heirarchy breadcrumbs
		$is_entity = is_entity($main_object);
		$is_aggregate = is_aggregate($main_object);
		$geo = get_geo($main_object);
		$hie = get_hie($main_object);
		$geo_level = get_geo_level($main_object);
		$hie_level = get_hie_level($main_object);

		$entity_specification = get_entity_specs($main_object);
		$geo_bread = get_geo_bread($main_object);
		$hie_bread = get_hie_bread($main_object);
		$geo_bread_names = get_geo_bread_names($main_object);
		$hie_bread_names = get_hie_bread_names($main_object);		
		
    draw_navigation(); // left navigation pane

		?>
		<script type="text/javascript">if (getWindowWidth() < 1600) toggleNav(); // hide navigation pane</script>
    <div class="info-wrapper">
    	<div class="info-content-wrapper">
      	<div class="info-content">
      
					<?php
						
						draw_bread(); // geography and hierarchy breadcrumbs
				
						draw_obj_name(); // object name - either entity or aggregate
						
						if ($is_entity)
						{
							draw_profile_head(); // disclaimer, properties, map
						}
          ?>
          
		    </div>
      </div>
    </div>
    <div class="years-wrapper">
    	<div class="years-content-wrapper">
      	<div class="years-content">
        
					<?php
						draw_years(); // panels with year selection
          ?>        
        
        </div>
      </div>
    </div>
    
    <?php

			// all content generated after panel with year selection can be cached and generated from cache
			// some content of the panel depents on cookies, so that part cannot be cached
			if ($GS["caching_enabled"])
				require_once('structure/caching-header.php'); 

			// get basic values
			foreach ($objects as $obj_string)
			{
				$numeric_data = get_data($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $years_a);
				$text_data = get_text_data($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $years_a);
				$data[] = $numeric_data[0] + $text_data[0]; // values itself
				$disc_data[] = $numeric_data[1] + $text_data[1]; // disclaimer IDs for some values (if needed)
				
				$I_array = get_indicators($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $GS["profile_indicator_rating"], $years_a);	
				$indicators[] = $I_array[0]; // values itself
				$disc_indicators[] = $I_array[1]; // disclaimer IDs for some values (if needed)
				
				$R_array = get_ratings($obj_string, $is_entity, $geo, $hie, $geo_level, $hie_level, $years_a);
				$ratings[] = $R_array[0]; // values itself
				$disc_ratings[] = $R_array[1]; // disclaimer IDs for some values (if needed)
			}
			
		?>
    
    <div class="body-content-wrapper">
    	<div class="body-content">
      	<div id="profile">
        
					<?php	
            $view = get_view($hie_a); // detect which data, indicators and ratings should be displayed for each object (entities with different hierarchy might have different types of data, indicators and ratings)
						
						// get specification for each type of data, indicator and rating
            if ($GS["max_data_level_allowed"] >= 0) $data_specs = get_specs("data", $view["data"][0]);
            if ($GS["max_indicator_level_allowed"] >= 0) $indicators_specs = get_specs("indicators", $view["indicators"][0]);
            if ($GS["max_rating_level_allowed"] >= 0) $ratings_specs = get_specs("ratings", $view["ratings"][0]);
            
						// detect which data, indicators and ratings do exist
            if ($GS["max_data_level_allowed"] >= 0) $data_existence = get_existence($view["data"]);
            if ($GS["max_indicator_level_allowed"] >= 0) $indicators_existence = get_existence($view["indicators"]);
            if ($GS["max_rating_level_allowed"] >= 0) $ratings_existence = get_existence($view["ratings"]);      
      
						// get disclaimers for current values
           	if ($GS["max_data_level_allowed"] >= 0)  $data_disclaimers = get_disclaimers("data", $disc_data);
            if ($GS["max_indicator_level_allowed"] >= 0) $indicator_disclaimers = get_disclaimers("indicators", $disc_indicators);
            if ($GS["max_rating_level_allowed"] >= 0) $rating_disclaimers = get_disclaimers("ratings", $disc_ratings);
            
						// draw values (with their disclaimers, based on existence and specification)						
            if ($GS["max_rating_level_allowed"] >= 0) draw_ratings($ratings_specs, $ratings_existence, $ratings, $rating_disclaimers);
            if ($GS["max_indicator_level_allowed"] >= 0) draw_indicators($indicators_specs, $indicators_existence, $indicators, $indicator_disclaimers);	
            if ($GS["max_data_level_allowed"] >= 0) draw_data($data_specs, $data_existence, $data, $data_disclaimers);
          ?>
    		</div>
		  </div>
	  </div>
        
	<?php
	}
	elseif (isset($_GET["all"])) // no object to show, address is :"/profile/all"
	{
	?>
  
    <div class="body-content-wrapper">
      <div class="body-content">
      	<div id="list-all">
      
					<?php
            draw_all_profiles($GS["all_profiles_column_count"]); // draw tree with all entities
          ?>
          
				</div>        
      </div>
    </div>
    
  <?php
	}
	elseif (!isset($_GET["all"]) && !isset($_GET["objects"]) && !isset($_GET["years"])) // draw 'default' profile page - specified by "profiles_layout" string
	{
		parse_display_string($GS["profiles_layout"]);		
	}
	else // trying to display object that does not exist
	{
	?>

  <div class="body-content-wrapper">
    <div class="body-content">
      
      <?php
        echo '<div class="main-error">'.$T["e_bad_object"].'</div>';
      ?>
    
    </div>
  </div>
  
  <?php
	}
?>

<?php
	require_once('structure/footer.php');
	
	if ($GS["caching_enabled"])
		require_once('structure/caching-footer.php');
?>