<?php
	require_once('include/connection.php'); // mysql connection
	require_once('include/preload.php'); // texts and global settings

	require_once('include/tables.php'); // basic tables with data structure
	require_once('include/support.php'); // support functions
	require_once('include/format.php'); // formatting and displaying text and data
	require_once('include/taxonomy.php'); // operating with data and its structure
	require_once('include/values.php'); // getting values from tables
	require_once('include/ui.php'); // displaying values in profiles, comparison rankings
	require_once('include/dialogs.php'); // windows used for navigation and selection

	require_once('structure/header.php');
	
	if ($GS["caching_enabled"])
		require_once('structure/caching-header.php'); // all content generated after main menu can be cached and generated from cache

	$PAGE = 'rankings';	// global variable used in functions for displaying values to determine how values should be displayed
?>

<script type="text/javascript" src="/js/jquery-1.11.1.min.js"></script>
<script type="text/javascript" src="/js/tipped.js"></script>

<script type="text/javascript">
	$(document).ready(function() {
		// initialize tooltips
		Tipped.create('.i-disclaimer', {fadeIn: 100, fadeOut: 100, behavior: 'hide'});
		Tipped.create('.legend', {fadeIn: 100, fadeOut: 100, behavior: 'hide'});
	});
</script>

<?php

	// ranking table consists of: 
	// - values (columns), 
	// - criteria (geography and hierarchy),
	// - display_string (pagination, column for sorting, sorting order)
	// - years (years used in ranking)
	// if some of this parameters are not set, get their default values
	
	if (isset($_GET["values"])) 
		$values_string = $_GET["values"]; 
	else 
		$values_string = $GS["main_rating"];
	$values_string = preg_replace('/\s+/', '', $values_string);
	if (!preg_match("/^[0-9a-zA-Z,]+$/", $values_string)) $values_string = $GS["main_rating"];
	
	if (isset($_GET["criteria"])) 
		$criteria_string = $_GET["criteria"]; 
	else 
		$criteria_string = $GS["default_ranking_criteria"];
	$criteria_string = preg_replace('/\s+/', '', $criteria_string);
	if (!preg_match("/^[0-9a-zA-Z,-]+$/", $criteria_string)) $criteria_string = $GS["default_ranking_criteria"];
	
	if (isset($_GET["display"]))
		$display_string = $_GET["display"];
	else
		$display_string = $GS["default_ranking_ordering"].',1-'.$GS["default_ranking_rows"];
	if (!preg_match("/^[0-9a-zA-Z,-]+$/", $display_string)) $display_string = $GS["default_ranking_ordering"].',1-'.$GS["default_ranking_rows"];
		
	if (isset($_GET["years"])) 
		$years_string = $_GET["years"]; 
	else 
		$years_string = $GS["newest_year"];
	if (!preg_match("/^[0-9]+$/", $years_string)) $years_string = $GS["newest_year"];
		
	$years = parse_years($years_string);
	
	// fetch data for ranking table based on four parameters mentioned above	
	$data = get_ranking_values($values_string, $criteria_string, $years_string, $display_string);
	// $data = [$IDs, $values, $weights, $entities, $columns, $found_rows_number]
	
	if ($years[1] == $years[0]) // displaying only one year - in this case, display also disclaimers
		$disclaimers = get_ranking_disclaimers($data[0], $data[3], $data[4]);
	else
		$disclaimers = NULL;
?>

<div class="years-wrapper">
  <div class="years-content-wrapper">
    <div class="years-content">
    
      <?php
        draw_years(); // draw panels with year selection
      ?>        
    
    </div>
  </div>
</div>

<?php 
	if ($data[1]) {
?>
<div class="rankings-wrapper">
	<div id="rankings-content-wrapper">
  	<div id="rankings-content">
    	<div id="rankings-selection">
      
				<?php
          draw_selection($values_string, $criteria_string, $years_string, $display_string); // left pane in rankings for selecting criteria - columns, geography, hierarchy

					draw_column_selection($values_string, $criteria_string, $years_string, $display_string); // window with column selection - hidden by default
					draw_geo_selection($values_string, $criteria_string, $years_string, $display_string); // window with geography selection - hidden by default
					draw_hie_selection($values_string, $criteria_string, $years_string, $display_string); // window with hierarchy selection - hidden by default
        ?>        
        
      </div>
      <div id="rankings">
  
        <?php
          draw_rankings($data, $values_string, $criteria_string, $years_string, $display_string, $disclaimers);	// draw table with values from get_ranking_values(...) itself
        ?>
        
      </div>
      <div class="clear"></div>
    </div>
  </div>
</div>
<?php 
	} 
	else 
	{ 
?>
<div class="body-content-wrapper">
  <div class="body-content">
    <div class="main-error">
      <?php
        echo $T["e_no_rankings_data_text"];
      ?>
    </div>
  </div>
</div>

<?php
	}
?>
<?php
	require_once('structure/footer.php');

	if ($GS["caching_enabled"])
		require_once('structure/caching-footer.php');
?>