<?php
	require_once('include/connection.php'); // mysql connection
	require_once('include/preload.php'); // texts and global settings

	require_once('include/tables.php'); // basic tables with data structure
	require_once('include/support.php'); // support functions
	require_once('include/format.php'); // formatting and displaying text and data
	require_once('include/taxonomy.php'); // operating with data and its structure
	require_once('include/values.php'); // getting values from tables
	require_once('include/trees.php'); // dealing with displaying 'trees' of all entities or while geography or hierarchy structure
	require_once('include/pages.php'); // dealing with text (non-data) pages
	require_once('include/search.php'); // searching functions
	
	if (isset($_GET["string"])) $search = $_GET["string"]; else $search = FALSE;
	
	if ($search)
	{
		// if one entity with exact search string was found, redirect
		$exact_found = search_exact_entities($search);
		if (count($exact_found) == 1)
		{
			$data = reset($exact_found);
			header("Location: /profile/".$data["ID"]."/".$GS["newest_year"]);
			die();
		}
		
		// in all four search methods, return found entities
		// search in entities name
		$direct_found = search_entities($search);
		$direct_found_count = count($direct_found[0]);
		// search in entities basic properties
		$entity_properties_found = search_entity_properties($search);
		$entity_properties_found_count = count($entity_properties_found);
		// search in geography elements names
		$geo_found = search_geo($search);
		$geo_found_count = count($geo_found);
		// search in hierarchy elements names
		$hie_found = search_hie($search);
		$hie_found_count = count($hie_found);
		
		// remove duplicates, assign search method to each found record
		if ($direct_found_count + $entity_properties_found_count + $geo_found_count + $hie_found_count > 0)
		
		{
			$final_elements = $direct_found[0];
			$final_search_strings = $direct_found[1];
			
			$c = 0;
			foreach ($geo_found[0] as $ID => $data)
			{
				if (!array_key_exists($ID, $final_elements))
				{
					$final_elements[$ID] = $data; // entity with its specification
					$final_search_strings[] = $geo_found[1][$c]; // search method entity was found with
				}
				$c++;
			}
			
			// the same as above
			$c = 0;
			foreach ($hie_found[0] as $ID => $data)
			{
				if (!array_key_exists($ID, $final_elements))
				{
					$final_elements[$ID] = $data;
					$final_search_strings[] = $hie_found[1][$c];
				}
				$c++;
			}

			// the same as above
			$c = 0;
			foreach ($entity_properties_found[0] as $ID => $data)
			{
				if (!array_key_exists($ID, $final_elements))
				{
					$final_elements[$ID] = $data;
					$final_search_strings[] = $entity_properties_found[1][$c];
				}
				$c++;
			}

		}
	}
	
	if (count($final_elements) == 1) // if only one element was found by all four methods, redirect
	{
		$data = reset($final_elements);
		header("Location: /profile/".$data["ID"]."/".$GS["newest_year"]);
		die();
	}
	
	require_once('structure/header.php');

	if ($GS["caching_enabled"])
		require_once('structure/caching-header.php'); // all content generated after main menu can be cached and generated from cache

	if ($search && count($final_elements) > 1) // something was searched, something was found
	{
		draw_search_results($final_elements, $T["search_results"], $final_search_strings);
	}
	
	elseif (isset($_GET["name"])) // nothing was searched, but first letter was selected (A - Z)
	{
		$name = $_GET["name"];
		if (!preg_match("/^[a-z]+$/", $name)) $name = '';
		$entities = search_entities($name, TRUE);
		if (count($entities[0]) > 0)
			draw_search_results($entities[0], $T["entities_beginning_with"].' "'.strtoupper($name).'"', FALSE);
		else
			display_error_page($T["e_no_search_results_found"]);
	}
	
	elseif (isset($_GET["object"])) // display "search" results for given geography and hierarchy
	{
		$object = $_GET["object"];
		if (!preg_match("/^[0-9a-zA-Z-]+$/", $object)) $object = NULL;
		if (is_aggregate($object))
		{
			$geo = get_geo($object);
			$hie = get_hie($object);
			$entities = get_entities($geo, $hie);
			draw_search_results($entities, ucfirst(get_obj_name($object, FALSE)), FALSE);
		}
		else
			display_error_page($T["e_no_search_results_found"]);
	}
	
	else // something wierd was searched
		display_error_page($T["e_no_search_results_found"]);

	require_once('structure/footer.php');

	if ($GS["caching_enabled"])
		require_once('structure/caching-footer.php');	
?>